@@ -93,7 +93,7 @@ function init() {
     "index/scripts",
     module,
     [
-      "scripts/index/jquery.contextMenu.min.js",
+      "scripts/index/jquery.contextMenu.js",
       "scripts/index/jquery.ui.position.js",
       "scripts/database-extension.js",
       "scripts/index/database-import-controller.js",
