@@ -58,14 +58,13 @@ import com.google.refine.model.Project;
 import com.google.refine.util.JSONUtilities;
 import com.google.refine.util.ParsingUtilities;
 
-
 public class DatabaseImportController implements ImportingController {
-    
+
     private static final Logger logger = LoggerFactory.getLogger("DatabaseImportController");
     protected RefineServlet servlet;
-    public static int DEFAULT_PREVIEW_LIMIT = 100; 
+    public static int DEFAULT_PREVIEW_LIMIT = 100;
     public static String OPTIONS_KEY = "options";
-    
+
     @Override
     public void init(RefineServlet servlet) {
         this.servlet = servlet;
@@ -73,32 +72,32 @@ public class DatabaseImportController implements ImportingController {
 
     @Override
     public void doGet(HttpServletRequest request, HttpServletResponse response)
-        throws ServletException, IOException {
+            throws ServletException, IOException {
         HttpUtilities.respond(response, "error", "GET not implemented");
     }
 
     @Override
     public void doPost(HttpServletRequest request, HttpServletResponse response)
-        throws ServletException, IOException {
-        if(logger.isDebugEnabled()){
+            throws ServletException, IOException {
+        if (logger.isDebugEnabled()) {
             logger.debug("doPost Query String::{}", request.getQueryString());
         }
         response.setCharacterEncoding("UTF-8");
         Properties parameters = ParsingUtilities.parseUrlParameters(request);
-        
+
         String subCommand = parameters.getProperty("subCommand");
-        
-        if(logger.isDebugEnabled()){
+
+        if (logger.isDebugEnabled()) {
             logger.info("doPost::subCommand::{}", subCommand);
         }
-        
+
         if ("initialize-parser-ui".equals(subCommand)) {
             doInitializeParserUI(request, response, parameters);
         } else if ("parse-preview".equals(subCommand)) {
             try {
-                
+
                 doParsePreview(request, response, parameters);
-                
+
             } catch (DatabaseServiceException e) {
                 logger.error("doPost::DatabaseServiceException::{}", e);
                 HttpUtilities.respond(response, "error", getDbServiceException(e));
@@ -110,17 +109,17 @@ public class DatabaseImportController implements ImportingController {
         }
 
     }
- 
+
     private String getDbServiceException(Exception ex) {
         String message = "";
-        if(ex instanceof DatabaseServiceException) {
+        if (ex instanceof DatabaseServiceException) {
             DatabaseServiceException dbEx = (DatabaseServiceException) ex;
-            if(dbEx.isSqlException()) {
-                message = message + dbEx.getSqlCode() + " " +  dbEx.getSqlState();
+            if (dbEx.isSqlException()) {
+                message = message + dbEx.getSqlCode() + " " + dbEx.getSqlState();
             }
         }
         message = message + ex.getMessage();
-        
+
         return message;
     }
 
@@ -134,112 +133,105 @@ public class DatabaseImportController implements ImportingController {
      */
     private void doInitializeParserUI(HttpServletRequest request, HttpServletResponse response, Properties parameters)
             throws ServletException, IOException {
-        if(logger.isDebugEnabled()) {
+        if (logger.isDebugEnabled()) {
             logger.debug("::doInitializeParserUI::");
         }
-        
 
         ObjectNode result = ParsingUtilities.mapper.createObjectNode();
         ObjectNode options = ParsingUtilities.mapper.createObjectNode();
         JSONUtilities.safePut(result, "status", "ok");
         JSONUtilities.safePut(result, OPTIONS_KEY, options);
 
-        JSONUtilities.safePut(options, "skipDataLines", 0); 
+        JSONUtilities.safePut(options, "skipDataLines", 0);
         JSONUtilities.safePut(options, "storeBlankRows", true);
         JSONUtilities.safePut(options, "storeBlankCellsAsNulls", true);
-        if(logger.isDebugEnabled()) {
+        if (logger.isDebugEnabled()) {
             logger.debug("doInitializeParserUI:::{}", result.toString());
         }
-       
+
         HttpUtilities.respond(response, result.toString());
 
     }
 
-
     /**
      * doParsePreview
+     * 
      * @param request
      * @param response
      * @param parameters
      * @throws ServletException
      * @throws IOException
-     * @throws DatabaseServiceException 
+     * @throws DatabaseServiceException
      */
     private void doParsePreview(
             HttpServletRequest request, HttpServletResponse response, Properties parameters)
-                throws ServletException, IOException, DatabaseServiceException {
-            if(logger.isDebugEnabled()) {
-                logger.debug("JobID::{}", parameters.getProperty("jobID"));
-            } 
-           
-            
-            long jobID = Long.parseLong(parameters.getProperty("jobID"));
-            ImportingJob job = ImportingManager.getJob(jobID);
-            if (job == null) {
-                HttpUtilities.respond(response, "error", "No such import job");
-                return;
-            }
-          
-            
-            DatabaseQueryInfo databaseQueryInfo = getQueryInfo(request);
-          
-            
-            if(databaseQueryInfo == null) {
-                HttpUtilities.respond(response, "error", "Invalid or missing Query Info");
-            }
-            
-            job.updating = true;
-            try {
-                ObjectNode optionObj = ParsingUtilities.evaluateJsonStringToObjectNode(
+            throws ServletException, IOException, DatabaseServiceException {
+        if (logger.isDebugEnabled()) {
+            logger.debug("JobID::{}", parameters.getProperty("jobID"));
+        }
+
+        long jobID = Long.parseLong(parameters.getProperty("jobID"));
+        ImportingJob job = ImportingManager.getJob(jobID);
+        if (job == null) {
+            HttpUtilities.respond(response, "error", "No such import job");
+            return;
+        }
+
+        DatabaseQueryInfo databaseQueryInfo = getQueryInfo(request);
+
+        if (databaseQueryInfo == null) {
+            HttpUtilities.respond(response, "error", "Invalid or missing Query Info");
+        }
+
+        job.updating = true;
+        try {
+            ObjectNode optionObj = ParsingUtilities.evaluateJsonStringToObjectNode(
                     request.getParameter("options"));
-                
-                List<Exception> exceptions = new LinkedList<Exception>();
-                
-                job.prepareNewProject();
-                
-                parsePreview(
+
+            List<Exception> exceptions = new LinkedList<Exception>();
+
+            job.prepareNewProject();
+
+            parsePreview(
                     databaseQueryInfo,
                     job.project,
                     job.metadata,
                     job,
-                    DEFAULT_PREVIEW_LIMIT ,
+                    DEFAULT_PREVIEW_LIMIT,
                     optionObj,
-                    exceptions
-                );
-                Writer w = response.getWriter();
-                JsonGenerator writer = ParsingUtilities.mapper.getFactory().createGenerator(w);
-                try {
-                    writer.writeStartObject();
-                    if (exceptions.size() == 0) {
-                        job.project.update(); // update all internal models, indexes, caches, etc.
-                        writer.writeStringField("status", "ok");
-                    } else {
-                        writer.writeStringField("status", "error");
-                        writer.writeStringField("message", getExceptionString(exceptions));
-                    }
-                    writer.writeEndObject();
-                } catch (IOException e) {
-                    throw new ServletException(e);
-                } finally {
-                    writer.flush();
-                    writer.close();
-                    w.flush();
-                    w.close();
+                    exceptions);
+            Writer w = response.getWriter();
+            JsonGenerator writer = ParsingUtilities.mapper.getFactory().createGenerator(w);
+            try {
+                writer.writeStartObject();
+                if (exceptions.size() == 0) {
+                    job.project.update(); // update all internal models, indexes, caches, etc.
+                    writer.writeStringField("status", "ok");
+                } else {
+                    writer.writeStringField("status", "error");
+                    writer.writeStringField("message", getExceptionString(exceptions));
                 }
-
+                writer.writeEndObject();
             } catch (IOException e) {
                 throw new ServletException(e);
             } finally {
-                job.touch();
-                job.updating = false;
+                writer.flush();
+                writer.close();
+                w.flush();
+                w.close();
             }
+
+        } catch (IOException e) {
+            throw new ServletException(e);
+        } finally {
+            job.touch();
+            job.updating = false;
         }
-
-
+    }
 
     private String getExceptionString(List<Exception> exceptions) {
         String ex = "";
-        for(Exception e: exceptions) {
+        for (Exception e : exceptions) {
             ex = ex + e.getLocalizedMessage() + "\n";
         }
         // TODO Auto-generated method stub
@@ -258,27 +250,24 @@ public class DatabaseImportController implements ImportingController {
      * @throws DatabaseServiceException
      */
     private static void parsePreview(
-            DatabaseQueryInfo dbQueryInfo, 
-            Project project, 
+            DatabaseQueryInfo dbQueryInfo,
+            Project project,
             ProjectMetadata metadata,
-            final ImportingJob job, 
-            int limit, 
+            final ImportingJob job,
+            int limit,
             ObjectNode options,
-            List<Exception> exceptions) throws DatabaseServiceException{
-        
-       
+            List<Exception> exceptions) throws DatabaseServiceException {
+
         DatabaseService databaseService = DatabaseService.get(dbQueryInfo.getDbConfig().getDatabaseType());
         String querySource = getQuerySource(dbQueryInfo);
-        
+
         List<DatabaseColumn> columns = databaseService.getColumns(dbQueryInfo.getDbConfig(), dbQueryInfo.getQuery());
-                
-        
+
         setProgress(job, querySource, -1);
 
         JSONUtilities.safePut(options, "ignoreLines", 0); // number of blank lines at the beginning to ignore
         JSONUtilities.safePut(options, "headerLines", 1); // number of header lines
 
-        
         TabularImportingParserBase.readTable(
                 project,
                 metadata,
@@ -287,96 +276,95 @@ public class DatabaseImportController implements ImportingController {
                 querySource,
                 limit,
                 options,
-                exceptions
-            );
-        
+                exceptions);
+
         setProgress(job, querySource, 100);
-       
+
     }
-  
 
     /**
      * doCreateProject
+     * 
      * @param request
      * @param response
      * @param parameters
      */
     private void doCreateProject(HttpServletRequest request, HttpServletResponse response, Properties parameters)
-            throws ServletException, IOException{
-            if(logger.isDebugEnabled()) {
-                logger.debug("DatabaseImportController::doCreateProject:::{}", parameters.getProperty("jobID"));
-            }
-            
-            long jobID = Long.parseLong(parameters.getProperty("jobID"));
-            final ImportingJob job = ImportingManager.getJob(jobID);
-            if (job == null) {
-                HttpUtilities.respond(response, "error", "No such import job");
-                return;
-            }
-            
-            final DatabaseQueryInfo databaseQueryInfo = getQueryInfo(request);
-            if(databaseQueryInfo == null) {
-                HttpUtilities.respond(response, "error", "Invalid or missing Query Info");
-            }
-            
-            job.updating = true;
-            try {
-                final ObjectNode optionObj = ParsingUtilities.evaluateJsonStringToObjectNode(
+            throws ServletException, IOException {
+        if (logger.isDebugEnabled()) {
+            logger.debug("DatabaseImportController::doCreateProject:::{}", parameters.getProperty("jobID"));
+        }
+
+        long jobID = Long.parseLong(parameters.getProperty("jobID"));
+        final ImportingJob job = ImportingManager.getJob(jobID);
+        if (job == null) {
+            HttpUtilities.respond(response, "error", "No such import job");
+            return;
+        }
+
+        final DatabaseQueryInfo databaseQueryInfo = getQueryInfo(request);
+        if (databaseQueryInfo == null) {
+            HttpUtilities.respond(response, "error", "Invalid or missing Query Info");
+        }
+
+        job.updating = true;
+        try {
+            final ObjectNode optionObj = ParsingUtilities.evaluateJsonStringToObjectNode(
                     request.getParameter("options"));
-                
-                final List<Exception> exceptions = new LinkedList<Exception>();
-                
-                job.setState("creating-project");
-                
-                final Project project = new Project();
-              
-                new Thread() {
-                    @Override
-                    public void run() {
-                        ProjectMetadata pm = new ProjectMetadata();
-                        pm.setName(JSONUtilities.getString(optionObj, "projectName", "Untitled"));
-                        pm.setEncoding(JSONUtilities.getString(optionObj, "encoding", "UTF-8"));                
-                        
-                        try {
-                            parseCreate(
+
+            final List<Exception> exceptions = new LinkedList<Exception>();
+
+            job.setState("creating-project");
+
+            final Project project = new Project();
+
+            new Thread() {
+
+                @Override
+                public void run() {
+                    ProjectMetadata pm = new ProjectMetadata();
+                    pm.setName(JSONUtilities.getString(optionObj, "projectName", "Untitled"));
+                    pm.setEncoding(JSONUtilities.getString(optionObj, "encoding", "UTF-8"));
+
+                    try {
+                        parseCreate(
                                 databaseQueryInfo,
                                 project,
                                 pm,
                                 job,
                                 -1,
                                 optionObj,
-                                exceptions
-                            );
-                        } catch (DatabaseServiceException e) {
-                            logger.error("DatabaseImportController::doCreateProject:::run{}", e);
-                           // throw new RuntimeException("DatabaseServiceException::", e);
-                        }
-                      
-                        if (!job.canceled) {
-                            if (exceptions.size() > 0) {
-                                job.setError(exceptions);
-                            } else {
-                                project.update(); // update all internal models, indexes, caches, etc.             
-                                ProjectManager.singleton.registerProject(project, pm);                               
-                                job.setState("created-project");
-                                job.setProjectID(project.id);
-                               // logger.info("DatabaseImportController::doCreateProject:::run::projectID :{}", project.id);
-                            }
-                            
-                            job.touch();
-                            job.updating = false;
-                        }
+                                exceptions);
+                    } catch (DatabaseServiceException e) {
+                        logger.error("DatabaseImportController::doCreateProject:::run{}", e);
+                        // throw new RuntimeException("DatabaseServiceException::", e);
                     }
-                }.start();
-                
-                HttpUtilities.respond(response, "ok", "done");
-            } catch (IOException e) {
-                throw new ServletException(e);
-            }
+
+                    if (!job.canceled) {
+                        if (exceptions.size() > 0) {
+                            job.setError(exceptions);
+                        } else {
+                            project.update(); // update all internal models, indexes, caches, etc.
+                            ProjectManager.singleton.registerProject(project, pm);
+                            job.setState("created-project");
+                            job.setProjectID(project.id);
+                            // logger.info("DatabaseImportController::doCreateProject:::run::projectID :{}",
+                            // project.id);
+                        }
+
+                        job.touch();
+                        job.updating = false;
+                    }
+                }
+            }.start();
+
+            HttpUtilities.respond(response, "ok", "done");
+        } catch (IOException e) {
+            throw new ServletException(e);
         }
-    
-   
-    /**   
+    }
+
+    /**
      * @param dbQueryInfo
      * @param project
      * @param metadata
@@ -387,27 +375,26 @@ public class DatabaseImportController implements ImportingController {
      * @throws DatabaseServiceException
      */
     private static void parseCreate(
-            DatabaseQueryInfo dbQueryInfo, 
-            Project project, 
+            DatabaseQueryInfo dbQueryInfo,
+            Project project,
             ProjectMetadata metadata,
-            final ImportingJob job, 
-            int limit, 
+            final ImportingJob job,
+            int limit,
             ObjectNode options,
-            List<Exception> exceptions) throws DatabaseServiceException{
-        
-        
+            List<Exception> exceptions) throws DatabaseServiceException {
+
         DatabaseService databaseService = DatabaseService.get(dbQueryInfo.getDbConfig().getDatabaseType());
         String querySource = getQuerySource(dbQueryInfo);
-        
-        List<DatabaseColumn> columns = databaseService.getColumns(dbQueryInfo.getDbConfig(), dbQueryInfo.getQuery());       
-        
+
+        List<DatabaseColumn> columns = databaseService.getColumns(dbQueryInfo.getDbConfig(), dbQueryInfo.getQuery());
+
         setProgress(job, querySource, -1);
 
         JSONUtilities.safePut(options, "ignoreLines", 0); // number of blank lines at the beginning to ignore
         JSONUtilities.safePut(options, "headerLines", 1); // number of header lines
-    
-        long startTime = System.currentTimeMillis() ;
-        
+
+        long startTime = System.currentTimeMillis();
+
         TabularImportingParserBase.readTable(
                 project,
                 metadata,
@@ -416,26 +403,25 @@ public class DatabaseImportController implements ImportingController {
                 querySource,
                 limit,
                 options,
-                exceptions
-            );
-        
-        long endTime = System.currentTimeMillis() ;
-        if(logger.isDebugEnabled()) {
+                exceptions);
+
+        long endTime = System.currentTimeMillis();
+        if (logger.isDebugEnabled()) {
             logger.debug("Execution Time: {}", endTime - startTime);
         }
-        
+
         setProgress(job, querySource, 100);
-     
+
     }
-    
+
     private static int getCreateBatchSize() {
         String propBatchSize = DatabaseModuleImpl.getImportCreateBatchSize();
         int batchSize = 100;
-        if(propBatchSize != null && !propBatchSize.isEmpty()) {
+        if (propBatchSize != null && !propBatchSize.isEmpty()) {
             try {
                 batchSize = Integer.parseInt(propBatchSize);
-            }catch(NumberFormatException nfe) {
-                
+            } catch (NumberFormatException nfe) {
+
             }
         }
         return batchSize;
@@ -451,40 +437,38 @@ public class DatabaseImportController implements ImportingController {
         jdbcConfig.setDatabaseType(request.getParameter("databaseType"));
         jdbcConfig.setDatabaseHost(request.getParameter("databaseServer"));
         try {
-        	jdbcConfig.setDatabasePort(Integer.parseInt(request.getParameter("databasePort")));
-        } catch(NumberFormatException nfE) {
-        	logger.error("getQueryInfo :: invalid database port ::{}", nfE);
+            jdbcConfig.setDatabasePort(Integer.parseInt(request.getParameter("databasePort")));
+        } catch (NumberFormatException nfE) {
+            logger.error("getQueryInfo :: invalid database port ::{}", nfE);
         }
         jdbcConfig.setDatabaseUser(request.getParameter("databaseUser"));
         jdbcConfig.setDatabasePassword(request.getParameter("databasePassword"));
         jdbcConfig.setDatabaseName(request.getParameter("initialDatabase"));
         jdbcConfig.setDatabaseSchema(request.getParameter("initialSchema"));
-        
+
         String query = request.getParameter("query");
-        if(logger.isDebugEnabled()) {
+        if (logger.isDebugEnabled()) {
             logger.debug("jdbcConfig::{}, query::{}", jdbcConfig, query);
         }
         if (jdbcConfig.getDatabaseHost() == null || jdbcConfig.getDatabaseName() == null
                 || jdbcConfig.getDatabasePassword() == null || jdbcConfig.getDatabaseType() == null
                 || jdbcConfig.getDatabaseUser() == null || query == null
-                || (jdbcConfig.getDatabasePort() == 0 &&  !"SQLite".equalsIgnoreCase(jdbcConfig.getDatabaseType()))) {
-            if(logger.isDebugEnabled()) {
+                || (jdbcConfig.getDatabasePort() == 0 && !"SQLite".equalsIgnoreCase(jdbcConfig.getDatabaseType()))) {
+            if (logger.isDebugEnabled()) {
                 logger.debug("Missing Database Configuration::{}", jdbcConfig);
             }
             return null;
         }
-        
+
         return new DatabaseQueryInfo(jdbcConfig, query);
     }
-   
 
     private static String getQuerySource(DatabaseQueryInfo dbQueryInfo) {
         String dbType = dbQueryInfo.getDbConfig().getDatabaseType();
         return DatabaseService.get(dbType).getDatabaseUrl(dbQueryInfo.getDbConfig());
     }
 
-
-    private static  void setProgress(ImportingJob job, String querySource, int percent) {
+    private static void setProgress(ImportingJob job, String querySource, int percent) {
         job.setProgress(percent, "Reading " + querySource);
     }
 }
