@@ -67,43 +67,42 @@ import com.google.refine.util.ParsingUtilities;
  *
  */
 public abstract class ProjectManager {
+
     // last n expressions used across all projects
     static public final int EXPRESSION_HISTORY_MAX = 100;
 
     // If a project has been idle this long, flush it from memory
     static protected final int PROJECT_FLUSH_DELAY = 1000 * 60 * 15; // 15 minutes
-    
+
     // Don't spend more than this much time saving projects if doing a quick save
     static protected final int QUICK_SAVE_MAX_TIME = 1000 * 30; // 30 secs
 
-
     protected Map<Long, ProjectMetadata> _projectsMetadata;
     protected Map<String, Integer> _projectsTags;// TagName, number of projects having that tag
-    protected PreferenceStore            _preferenceStore;
+    protected PreferenceStore _preferenceStore;
 
     final static Logger logger = LoggerFactory.getLogger("ProjectManager");
 
     /**
-     *  What caches the lookups of projects.
+     * What caches the lookups of projects.
      */
     transient protected LookupCacheManager _lookupCacheManager = new LookupCacheManager();
 
     /**
-     *  Flag for heavy operations like creating or importing projects.  Workspace saves are skipped while it's set.
+     * Flag for heavy operations like creating or importing projects. Workspace saves are skipped while it's set.
      */
     transient protected int _busy = 0;
 
     /**
-     *  While each project's metadata is loaded completely at start-up, each project's raw data
-     *  is loaded only when the project is accessed by the user. This is because project
-     *  metadata is tiny compared to raw project data. This hash map from project ID to project
-     *  is more like a last accessed-last out cache.
+     * While each project's metadata is loaded completely at start-up, each project's raw data is loaded only when the
+     * project is accessed by the user. This is because project metadata is tiny compared to raw project data. This hash
+     * map from project ID to project is more like a last accessed-last out cache.
      */
     transient protected Map<Long, Project> _projects;
 
     static public ProjectManager singleton;
 
-    protected ProjectManager(){
+    protected ProjectManager() {
         _projectsMetadata = new HashMap<Long, ProjectMetadata>();
         _preferenceStore = new PreferenceStore();
         _projects = new HashMap<Long, Project>();
@@ -111,7 +110,7 @@ public abstract class ProjectManager {
 
         preparePreferenceStore(_preferenceStore);
     }
-    
+
     public void dispose() {
         save(true); // complete save
 
@@ -120,13 +119,14 @@ public abstract class ProjectManager {
                 project.dispose();
             }
         }
-        
+
         _projects.clear();
         _projectsMetadata.clear();
     }
 
     /**
      * Registers the project in the memory of the current session
+     * 
      * @param project
      * @param projectMetadata
      */
@@ -139,11 +139,11 @@ public abstract class ProjectManager {
             String[] tags = projectMetadata.getTags();
             if (tags != null) {
                 for (String tag : tags) {
-                        if (_projectsTags.containsKey(tag)) {
-                            _projectsTags.put(tag, _projectsTags.get(tag) + 1);
-                        } else {
-                            _projectsTags.put(tag, 1);
-                        }
+                    if (_projectsTags.containsKey(tag)) {
+                        _projectsTags.put(tag, _projectsTags.get(tag) + 1);
+                    } else {
+                        _projectsTags.put(tag, 1);
+                    }
                 }
             }
         }
@@ -151,6 +151,7 @@ public abstract class ProjectManager {
 
     /**
      * Load project metadata from data storage
+     * 
      * @param projectID
      * @return
      */
@@ -158,6 +159,7 @@ public abstract class ProjectManager {
 
     /**
      * Loads a project from the data store into memory
+     * 
      * @param id
      * @return
      */
@@ -165,6 +167,7 @@ public abstract class ProjectManager {
 
     /**
      * Import project from a Refine archive
+     * 
      * @param projectID
      * @param inputStream
      * @param gziped
@@ -174,19 +177,20 @@ public abstract class ProjectManager {
 
     /**
      * Export project to a Refine archive
+     * 
      * @param projectId
      * @param tos
      * @throws IOException
      */
     public abstract void exportProject(long projectId, TarArchiveOutputStream tos) throws IOException;
 
-
     /**
      * Saves a project and its metadata to the data store
+     * 
      * @param id
      */
     public void ensureProjectSaved(long id) {
-        synchronized(this){
+        synchronized (this) {
             ProjectMetadata metadata = this.getProjectMetadata(id);
             if (metadata != null) {
                 try {
@@ -194,7 +198,7 @@ public abstract class ProjectManager {
                 } catch (Exception e) {
                     e.printStackTrace();
                 }
-            }//FIXME what should be the behaviour if metadata is null? i.e. not found
+            } // FIXME what should be the behaviour if metadata is null? i.e. not found
 
             Project project = getProject(id);
             if (project != null && metadata != null && metadata.getModified().isAfter(project.getLastSave())) {
@@ -203,14 +207,15 @@ public abstract class ProjectManager {
                 } catch (Exception e) {
                     e.printStackTrace();
                 }
-            }//FIXME what should be the behaviour if project is null? i.e. not found or loaded.
-            //FIXME what should happen if the metadata is found, but not the project? or vice versa?
+            } // FIXME what should be the behaviour if project is null? i.e. not found or loaded.
+              // FIXME what should happen if the metadata is found, but not the project? or vice versa?
         }
 
     }
 
     /**
      * Save project metadata to the data store
+     * 
      * @param metadata
      * @param projectId
      * @throws Exception
@@ -219,13 +224,15 @@ public abstract class ProjectManager {
 
     /**
      * Save project to the data store
+     * 
      * @param project
-     * @throws IOException 
+     * @throws IOException
      */
     protected abstract void saveProject(Project project) throws IOException;
 
     /**
      * Save workspace and all projects to data store
+     * 
      * @param allModified
      */
     public void save(boolean allModified) {
@@ -241,10 +248,11 @@ public abstract class ProjectManager {
     protected abstract void saveWorkspace();
 
     /**
-     * A utility class to prioritize projects for saving, depending on how long ago
-     * they have been changed but have not been saved.
+     * A utility class to prioritize projects for saving, depending on how long ago they have been changed but have not
+     * been saved.
      */
     static protected class SaveRecord {
+
         final Project project;
         final long overdue;
 
@@ -256,44 +264,48 @@ public abstract class ProjectManager {
 
     /**
      * Saves all projects to the data store
+     * 
      * @param allModified
      */
     protected void saveProjects(boolean allModified) {
         List<SaveRecord> records = new ArrayList<SaveRecord>();
         LocalDateTime startTimeOfSave = LocalDateTime.now();
-        
+
         synchronized (this) {
             for (long id : _projectsMetadata.keySet()) {
                 ProjectMetadata metadata = getProjectMetadata(id);
                 Project project = _projects.get(id); // don't call getProject() as that will load the project.
 
                 if (project != null) {
-                    boolean hasUnsavedChanges =
-                        metadata.getModified().atZone(ZoneId.systemDefault()).toInstant().toEpochMilli() >= project.getLastSave().atZone(ZoneId.systemDefault()).toInstant().toEpochMilli();
+                    boolean hasUnsavedChanges = metadata.getModified().atZone(ZoneId.systemDefault()).toInstant().toEpochMilli() >= project
+                            .getLastSave().atZone(ZoneId.systemDefault()).toInstant().toEpochMilli();
                     // We use >= instead of just > to avoid the case where a newly created project
                     // has the same modified and last save times, resulting in the project not getting
                     // saved at all.
 
                     if (hasUnsavedChanges) {
-                        long msecsOverdue = startTimeOfSave.atZone(ZoneId.systemDefault()).toInstant().toEpochMilli() - project.getLastSave().atZone(ZoneId.systemDefault()).toInstant().toEpochMilli();
+                        long msecsOverdue = startTimeOfSave.atZone(ZoneId.systemDefault()).toInstant().toEpochMilli()
+                                - project.getLastSave().atZone(ZoneId.systemDefault()).toInstant().toEpochMilli();
 
                         records.add(new SaveRecord(project, msecsOverdue));
 
                     } else if (!project.getProcessManager().hasPending()
-                              && startTimeOfSave.atZone(ZoneId.systemDefault()).toInstant().toEpochMilli() - project.getLastSave().atZone(ZoneId.systemDefault()).toInstant().toEpochMilli() > PROJECT_FLUSH_DELAY) {
-                        
+                            && startTimeOfSave.atZone(ZoneId.systemDefault()).toInstant().toEpochMilli() - project.getLastSave()
+                                    .atZone(ZoneId.systemDefault()).toInstant().toEpochMilli() > PROJECT_FLUSH_DELAY) {
+
                         /*
-                         *  It's been a while since the project was last saved and it hasn't been
-                         *  modified. We can safely remove it from the cache to save some memory.
+                         * It's been a while since the project was last saved and it hasn't been modified. We can safely
+                         * remove it from the cache to save some memory.
                          */
                         _projects.remove(id).dispose();
                     }
                 }
             }
         }
-        
+
         if (records.size() > 0) {
             Collections.sort(records, new Comparator<SaveRecord>() {
+
                 @Override
                 public int compare(SaveRecord o1, SaveRecord o2) {
                     if (o1.overdue < o2.overdue) {
@@ -306,16 +318,11 @@ public abstract class ProjectManager {
                 }
             });
 
-            logger.info(allModified ?
-                "Saving all modified projects ..." :
-                "Saving some modified projects ..."
-            );
+            logger.info(allModified ? "Saving all modified projects ..." : "Saving some modified projects ...");
 
-            for (int i = 0;
-                 i < records.size() &&
-                    (allModified || (LocalDateTime.now().atZone(ZoneId.systemDefault()).toInstant().toEpochMilli() - 
-                            startTimeOfSave.atZone(ZoneId.systemDefault()).toInstant().toEpochMilli() < QUICK_SAVE_MAX_TIME));
-                 i++) {
+            for (int i = 0; i < records.size() &&
+                    (allModified || (LocalDateTime.now().atZone(ZoneId.systemDefault()).toInstant().toEpochMilli() -
+                            startTimeOfSave.atZone(ZoneId.systemDefault()).toInstant().toEpochMilli() < QUICK_SAVE_MAX_TIME)); i++) {
 
                 try {
                     saveProject(records.get(i).project);
@@ -336,9 +343,10 @@ public abstract class ProjectManager {
             for (long id : _projectsMetadata.keySet()) {
                 ProjectMetadata metadata = getProjectMetadata(id);
                 Project project = _projects.get(id);
-                if (project != null && !project.getProcessManager().hasPending() 
-                        && metadata.getModified().atZone(ZoneId.systemDefault()).toInstant().toEpochMilli() < project.getLastSave().atZone(ZoneId.systemDefault()).toInstant().toEpochMilli()) {
-                        _projects.remove(id).dispose();
+                if (project != null && !project.getProcessManager().hasPending()
+                        && metadata.getModified().atZone(ZoneId.systemDefault()).toInstant().toEpochMilli() < project.getLastSave()
+                                .atZone(ZoneId.systemDefault()).toInstant().toEpochMilli()) {
+                    _projects.remove(id).dispose();
                 }
             }
         }
@@ -353,8 +361,8 @@ public abstract class ProjectManager {
     }
 
     /**
-     * Gets the project metadata from memory
-     * Requires that the metadata has already been loaded from the data store
+     * Gets the project metadata from memory Requires that the metadata has already been loaded from the data store
+     * 
      * @param id
      * @return
      */
@@ -363,8 +371,8 @@ public abstract class ProjectManager {
     }
 
     /**
-     * Gets the project metadata from memory
-     * Requires that the metadata has already been loaded from the data store
+     * Gets the project metadata from memory Requires that the metadata has already been loaded from the data store
+     * 
      * @param name
      * @return
      */
@@ -378,14 +386,14 @@ public abstract class ProjectManager {
     }
 
     /**
-     * Tries to find the project id when given a project name
-     * Requires that all project metadata exists has been loaded to memory from the data store
+     * Tries to find the project id when given a project name Requires that all project metadata exists has been loaded
+     * to memory from the data store
+     * 
      * @param name
-     *     The name of the project
-     * @return
-     *     The id of the project
+     *            The name of the project
+     * @return The id of the project
      * @throws GetProjectIDException
-     *     If no unique project is found with the given name
+     *             If no unique project is found with the given name
      */
     public long getProjectID(String name) throws GetProjectIDException {
         Integer c = 0;
@@ -399,43 +407,44 @@ public abstract class ProjectManager {
         if (c == 1) {
             return id;
         } else if (c == 0) {
-            throw new GetProjectIDException("Unable to find project with name: " + name); 
+            throw new GetProjectIDException("Unable to find project with name: " + name);
         } else {
-            throw new GetProjectIDException(c + " projects found with name: " + name); 
+            throw new GetProjectIDException(c + " projects found with name: " + name);
         }
     }
-    
+
     /**
      * A valid user meta data definition should have name and display property
+     * 
      * @param placeHolderJsonObj
      * @return
      */
     private boolean isValidUserMetadataDefinition(ObjectNode placeHolderJsonObj) {
         return (placeHolderJsonObj != null &&
                 placeHolderJsonObj.has("name") &&
-            placeHolderJsonObj.has("display"));
+                placeHolderJsonObj.has("display"));
     }
-    
+
     public void mergeEmptyUserMetadata(ProjectMetadata metadata) {
         if (metadata == null)
             return;
-        
+
         // place holder
         ArrayNode userMetadataPreference = null;
         // actual metadata for project
         ArrayNode jsonObjArray = metadata.getUserMetadata();
-        
+
         initDisplay(jsonObjArray);
-        
-        String userMeta = (String)_preferenceStore.get(PreferenceStore.USER_METADATA_KEY);
+
+        String userMeta = (String) _preferenceStore.get(PreferenceStore.USER_METADATA_KEY);
         if (userMeta == null)
             return;
         userMetadataPreference = ParsingUtilities.mapper.createArrayNode();
-        
+
         for (int index = 0; index < userMetadataPreference.size(); index++) {
             boolean found = false;
             ObjectNode placeHolderJsonObj = (ObjectNode) userMetadataPreference.get(index);
-            
+
             if (!isValidUserMetadataDefinition(placeHolderJsonObj)) {
                 logger.warn("Skipped invalid user metadata definition" + placeHolderJsonObj.toString());
                 continue;
@@ -444,9 +453,9 @@ public abstract class ProjectManager {
             for (int i = 0; i < jsonObjArray.size(); i++) {
                 JsonNode jsonObj = jsonObjArray.get(i);
                 if (!(jsonObj instanceof ObjectNode)) {
-                	continue;
+                    continue;
                 }
-                ObjectNode node = (ObjectNode)jsonObj;
+                ObjectNode node = (ObjectNode) jsonObj;
                 if (node.get("name").asText("").equals(placeHolderJsonObj.get("name").asText(""))) {
                     found = true;
                     node.set("display", placeHolderJsonObj.get("display"));
@@ -460,12 +469,13 @@ public abstract class ProjectManager {
                 logger.info("Put the placeholder {} for project {}",
                         placeHolderJsonObj.get("name").asText(""),
                         metadata.getName());
-            } 
+            }
         }
     }
-    
+
     /**
      * honor the meta data preference
+     * 
      * @param jsonObjArray
      */
     private void initDisplay(ArrayNode jsonObjArray) {
@@ -479,17 +489,18 @@ public abstract class ProjectManager {
 
     /**
      * Gets all the project Metadata currently held in memory.
+     * 
      * @return
      */
     @JsonIgnore
     public Map<Long, ProjectMetadata> getAllProjectMetadata() {
-        for(Project project : _projects.values()) {
+        for (Project project : _projects.values()) {
             mergeEmptyUserMetadata(project.getMetadata());
         }
-            
+
         return _projectsMetadata;
     }
-    
+
     /**
      * Gets all the project tags currently held in memory
      * 
@@ -497,16 +508,16 @@ public abstract class ProjectManager {
      */
     @JsonIgnore
     public Map<String, Integer> getAllProjectTags() {
-      return _projectsTags;
+        return _projectsTags;
     }
 
     /**
-     * Gets the required project from the data store
-     * If project does not already exist in memory, it is loaded from the data store
+     * Gets the required project from the data store If project does not already exist in memory, it is loaded from the
+     * data store
+     * 
      * @param id
-     *     the id of the project
-     * @return
-     *     the project with the matching id, or null if it can't be found
+     *            the id of the project
+     * @return the project with the matching id, or null if it can't be found
      */
     public Project getProject(long id) {
         synchronized (this) {
@@ -515,7 +526,7 @@ public abstract class ProjectManager {
             } else {
                 Project project = loadProject(id);
                 if (project != null) {
-                    _projects.put(id, project);                    
+                    _projects.put(id, project);
                 }
                 return project;
             }
@@ -524,6 +535,7 @@ public abstract class ProjectManager {
 
     /**
      * Gets the preference store
+     * 
      * @return
      */
     @JsonProperty("preferences")
@@ -533,6 +545,7 @@ public abstract class ProjectManager {
 
     /**
      * Gets all expressions from the preference store
+     * 
      * @return
      */
     @JsonIgnore
@@ -542,14 +555,15 @@ public abstract class ProjectManager {
 
     /**
      * The history entry manager deals with changes
+     * 
      * @return manager for handling history
      */
     @JsonIgnore
     public abstract HistoryEntryManager getHistoryEntryManager();
 
-
     /**
      * Remove the project from the data store
+     * 
      * @param project
      */
     public void deleteProject(Project project) {
@@ -558,15 +572,17 @@ public abstract class ProjectManager {
 
     /**
      * Remove project from data store
+     * 
      * @param projectID
      */
     public abstract void deleteProject(long projectID);
 
     /**
      * Removes project from memory
+     * 
      * @param projectID
      */
-    protected void removeProject(long projectID){
+    protected void removeProject(long projectID) {
         if (_projects.containsKey(projectID)) {
             _projects.remove(projectID).dispose();
         }
@@ -575,10 +591,9 @@ public abstract class ProjectManager {
         }
     }
 
-
     /**
-     * Sets the flag for long running operations.  This will prevent
-     * workspace saves from happening while it's set.
+     * Sets the flag for long running operations. This will prevent workspace saves from happening while it's set.
+     * 
      * @param busy
      */
     public void setBusy(boolean busy) {
@@ -591,10 +606,9 @@ public abstract class ProjectManager {
         }
     }
 
-
-
     /**
      * Add the latest expression to the preference store
+     * 
      * @param s
      */
     public void addLatestExpression(String s) {
@@ -603,13 +617,12 @@ public abstract class ProjectManager {
         }
     }
 
-
     /**
-    *
-    * @param ps
-    */
-   static protected void preparePreferenceStore(PreferenceStore ps) {
-       ps.put("scripting.expressions", new TopList(EXPRESSION_HISTORY_MAX));
-       ps.put("scripting.starred-expressions", new TopList(Integer.MAX_VALUE));
-   }
+     *
+     * @param ps
+     */
+    static protected void preparePreferenceStore(PreferenceStore ps) {
+        ps.put("scripting.expressions", new TopList(EXPRESSION_HISTORY_MAX));
+        ps.put("scripting.starred-expressions", new TopList(Integer.MAX_VALUE));
+    }
 }
