@@ -71,18 +71,19 @@ public class ScatterplotFacet implements Facet {
 
     public static final int LIN = 0;
     public static final int LOG = 1;
-    
+
     public static final int NO_ROTATION = 0;
     public static final int ROTATE_CW = 1;
     public static final int ROTATE_CCW = 2;
-    
+
     /*
      * Configuration, from the client side
      */
     public static class ScatterplotFacetConfig implements FacetConfig {
+
         @JsonProperty("name")
         protected String name; // name of facet
-    
+
         @JsonProperty(X_EXPRESSION)
         protected String expression_x; // expression to compute the x numeric value(s) per row
         @JsonProperty(Y_EXPRESSION)
@@ -91,7 +92,7 @@ public class ScatterplotFacet implements Facet {
         protected String columnName_x; // column to base the x expression on, if any
         @JsonProperty(Y_COLUMN_NAME)
         protected String columnName_y; // column to base the y expression on, if any
-        
+
         @JsonProperty(SIZE)
         protected int size;
         @JsonIgnore
@@ -102,19 +103,20 @@ public class ScatterplotFacet implements Facet {
         protected String rotation_str;
         @JsonIgnore
         protected int rotation;
-    
+
         @JsonIgnore
         protected double l = 1.;
         @JsonProperty(DOT)
         protected double dot;
-    
+
         @JsonIgnore
         protected String color_str = "000000";
+
         @JsonIgnore
         protected Color getColor() {
-            return new Color(Integer.parseInt(color_str,16));
+            return new Color(Integer.parseInt(color_str, 16));
         }
-        
+
         @JsonProperty(FROM_X)
         protected double from_x; // the numeric selection for the x axis, from 0 to 1
         @JsonProperty(TO_X)
@@ -123,30 +125,30 @@ public class ScatterplotFacet implements Facet {
         protected double from_y; // the numeric selection for the y axis, from 0 to 1
         @JsonProperty(TO_Y)
         protected double to_y;
-        
+
         // false if we're certain that all rows will match
         // and there isn't any filtering to do
         protected boolean isSelected() {
             return from_x > 0 || to_x < 1 || from_y > 0 || to_y < 1;
         }
-        
+
         @JsonProperty(DIM_X)
         public String getDimX() {
             return dim_x == LIN ? "lin" : "log";
         }
-        
+
         @JsonProperty(DIM_Y)
         public String getDimY() {
             return dim_y == LIN ? "lin" : "log";
         }
-        
+
         @Override
         public ScatterplotFacet apply(Project project) {
             ScatterplotFacet facet = new ScatterplotFacet();
             facet.initializeFromConfig(this, project);
             return facet;
         }
-        
+
         public static int getRotation(String rotation) {
             rotation = rotation.toLowerCase();
             if ("cw".equals(rotation) || "right".equals(rotation)) {
@@ -163,27 +165,27 @@ public class ScatterplotFacet implements Facet {
             return "scatterplot";
         }
     }
+
     ScatterplotFacetConfig config;
 
     /*
      * Derived configuration data
      */
-    protected int        columnIndex_x;
-    protected int        columnIndex_y;
-    protected Evaluable  eval_x;
-    protected Evaluable  eval_y;
-    protected String     errorMessage_x;
-    protected String     errorMessage_y;
+    protected int columnIndex_x;
+    protected int columnIndex_y;
+    protected Evaluable eval_x;
+    protected Evaluable eval_y;
+    protected String errorMessage_x;
+    protected String errorMessage_y;
 
-    protected double min_x; 
+    protected double min_x;
     protected double max_x;
     protected double min_y;
     protected double max_y;
     protected AffineTransform t;
-    
+
     protected String image;
-    
-        
+
     public static final String NAME = "name";
     public static final String IMAGE = "image";
     public static final String COLOR = "color";
@@ -201,7 +203,7 @@ public class ScatterplotFacet implements Facet {
     public static final String TO_X = "to_x";
     public static final String FROM_X = "from_x";
     public static final String ERROR_X = "error_x";
-    
+
     public static final String Y_COLUMN_NAME = "cy";
     public static final String Y_EXPRESSION = "ey";
     public static final String MIN_Y = "min_y";
@@ -209,13 +211,13 @@ public class ScatterplotFacet implements Facet {
     public static final String TO_Y = "to_y";
     public static final String FROM_Y = "from_y";
     public static final String ERROR_Y = "error_y";
-    
+
     private static final boolean IMAGE_URI = false;
-    
+
     public static String EMPTY_IMAGE;
-    
+
     final static Logger logger = LoggerFactory.getLogger("scatterplot_facet");
-    
+
     static {
         try {
             EMPTY_IMAGE = serializeImage(new BufferedImage(1, 1, BufferedImage.TYPE_4BYTE_ABGR));
@@ -223,77 +225,77 @@ public class ScatterplotFacet implements Facet {
             EMPTY_IMAGE = "";
         }
     }
-    
+
     @JsonProperty(NAME)
     public String getName() {
         return config.name;
     }
-    
+
     @JsonProperty(X_COLUMN_NAME)
     public String getXColumnName() {
         return config.columnName_x;
     }
-    
+
     @JsonProperty(X_EXPRESSION)
     public String getXExpression() {
         return config.expression_x;
     }
-    
+
     @JsonProperty(Y_COLUMN_NAME)
     public String getYColumnName() {
         return config.columnName_y;
     }
-    
+
     @JsonProperty(Y_EXPRESSION)
     public String getYExpression() {
         return config.expression_y;
     }
-    
+
     @JsonProperty(SIZE)
     public int getSize() {
         return config.size;
     }
-    
+
     @JsonProperty(DIM_X)
     public int getDimX() {
         return config.dim_x;
     }
-    
+
     @JsonProperty(DIM_Y)
     public int getDimY() {
         return config.dim_y;
     }
-    
+
     @JsonProperty(DOT)
     public double getDot() {
         return config.dot;
     }
-    
+
     @JsonProperty(ROTATION)
     public double getRotation() {
         return config.rotation;
     }
-    
+
     @JsonProperty(COLOR)
     public String getColorString() {
         return config.color_str;
     }
-    
+
     @JsonProperty(IMAGE)
     @JsonInclude(Include.NON_NULL)
     public String getImage() {
-        if(IMAGE_URI) {
+        if (IMAGE_URI) {
             return image;
         }
         return null;
     }
-    
+
     @JsonProperty(ERROR_X)
     @JsonInclude(Include.NON_NULL)
     public String getErrorX() {
         return errorMessage_x;
     }
-    
+
     @JsonProperty(FROM_X)
     @JsonInclude(Include.NON_NULL)
     public Double getFromX() {
@@ -302,7 +304,7 @@ public class ScatterplotFacet implements Facet {
         }
         return null;
     }
-    
+
     @JsonProperty(TO_X)
     @JsonInclude(Include.NON_NULL)
     public Double getToX() {
@@ -311,13 +313,13 @@ public class ScatterplotFacet implements Facet {
         }
         return null;
     }
-    
+
     @JsonProperty(ERROR_Y)
     @JsonInclude(Include.NON_NULL)
     public String getErrorY() {
         return errorMessage_y;
     }
-    
+
     @JsonProperty(FROM_Y)
     @JsonInclude(Include.NON_NULL)
     public Double getFromY() {
@@ -326,7 +328,7 @@ public class ScatterplotFacet implements Facet {
         }
         return null;
     }
-    
+
     @JsonProperty(TO_Y)
     @JsonInclude(Include.NON_NULL)
     public Double getToY() {
@@ -335,17 +337,17 @@ public class ScatterplotFacet implements Facet {
         }
         return null;
     }
-     
+
     public void initializeFromConfig(ScatterplotFacetConfig configuration, Project project) {
         config = configuration;
-        
+
         t = createRotationMatrix(config.rotation, config.l);
-        
+
         if (config.columnName_x.length() > 0) {
             Column x_column = project.columnModel.getColumnByName(config.columnName_x);
             if (x_column != null) {
                 columnIndex_x = x_column.getCellIndex();
-                
+
                 NumericBinIndex index_x = ScatterplotFacet.getBinIndex(project, x_column, eval_x, config.expression_x);
                 min_x = index_x.getMin();
                 max_x = index_x.getMax();
@@ -355,18 +357,18 @@ public class ScatterplotFacet implements Facet {
         } else {
             columnIndex_x = -1;
         }
-        
+
         try {
             eval_x = MetaParser.parse(config.expression_x);
         } catch (ParsingException e) {
             errorMessage_x = e.getMessage();
         }
-        
+
         if (config.columnName_y.length() > 0) {
             Column y_column = project.columnModel.getColumnByName(config.columnName_y);
             if (y_column != null) {
                 columnIndex_y = y_column.getCellIndex();
-                
+
                 NumericBinIndex index_y = ScatterplotFacet.getBinIndex(project, y_column, eval_y, config.expression_y);
                 min_y = index_y.getMin();
                 max_y = index_y.getMax();
@@ -376,32 +378,31 @@ public class ScatterplotFacet implements Facet {
         } else {
             columnIndex_y = -1;
         }
-        
+
         try {
             eval_y = MetaParser.parse(config.expression_y);
         } catch (ParsingException e) {
             errorMessage_y = e.getMessage();
         }
-        
+
     }
 
     @Override
     public RowFilter getRowFilter(Project project) {
-        if (config.isSelected() && 
-            eval_x != null && errorMessage_x == null && 
-            eval_y != null && errorMessage_y == null) 
-        {
+        if (config.isSelected() &&
+                eval_x != null && errorMessage_x == null &&
+                eval_y != null && errorMessage_y == null) {
             return new DualExpressionsNumberComparisonRowFilter(
                     eval_x, config.columnName_x, columnIndex_x, eval_y, config.columnName_y, columnIndex_y) {
-                
+
                 double from_x_pixels = config.from_x * config.l;
                 double to_x_pixels = config.to_x * config.l;
                 double from_y_pixels = config.from_y * config.l;
                 double to_y_pixels = config.to_y * config.l;
-                
+
                 @Override
                 protected boolean checkValues(double x, double y) {
-                    Point2D.Double p = new Point2D.Double(x,y);
+                    Point2D.Double p = new Point2D.Double(x, y);
                     p = translateCoordinates(p, min_x, max_x, min_y, max_y, config.dim_x, config.dim_y, config.l, t);
                     return p.x >= from_x_pixels && p.x <= to_x_pixels && p.y >= from_y_pixels && p.y <= to_y_pixels;
                 };
@@ -422,20 +423,19 @@ public class ScatterplotFacet implements Facet {
         if (eval_x != null && eval_y != null && errorMessage_x == null && errorMessage_y == null) {
             Column column_x = project.columnModel.getColumnByCellIndex(columnIndex_x);
             NumericBinIndex index_x = getBinIndex(project, column_x, eval_x, config.expression_x, "row-based");
-            
+
             Column column_y = project.columnModel.getColumnByCellIndex(columnIndex_y);
             NumericBinIndex index_y = getBinIndex(project, column_y, eval_y, config.expression_y, "row-based");
 
             retrieveDataFromBinIndices(index_x, index_y);
-            
+
             if (IMAGE_URI) {
                 if (index_x.isNumeric() && index_y.isNumeric()) {
                     ScatterplotDrawingRowVisitor drawer = new ScatterplotDrawingRowVisitor(
-                      columnIndex_x, columnIndex_y, min_x, max_x, min_y, max_y, 
-                      config.size, config.dim_x, config.dim_y, config.rotation, config.dot, config.getColor()
-                    );
+                            columnIndex_x, columnIndex_y, min_x, max_x, min_y, max_y,
+                            config.size, config.dim_x, config.dim_y, config.rotation, config.dot, config.getColor());
                     filteredRows.accept(project, drawer);
-                 
+
                     try {
                         image = serializeImage(drawer.getImage());
                     } catch (IOException e) {
@@ -447,26 +447,25 @@ public class ScatterplotFacet implements Facet {
             }
         }
     }
-    
+
     @Override
     public void computeChoices(Project project, FilteredRecords filteredRecords) {
         if (eval_x != null && eval_y != null && errorMessage_x == null && errorMessage_y == null) {
             Column column_x = project.columnModel.getColumnByCellIndex(columnIndex_x);
             NumericBinIndex index_x = getBinIndex(project, column_x, eval_x, config.expression_x, "record-based");
-            
+
             Column column_y = project.columnModel.getColumnByCellIndex(columnIndex_y);
             NumericBinIndex index_y = getBinIndex(project, column_y, eval_y, config.expression_y, "record-based");
-            
+
             retrieveDataFromBinIndices(index_x, index_y);
-            
+
             if (IMAGE_URI) {
                 if (index_x.isNumeric() && index_y.isNumeric()) {
                     ScatterplotDrawingRowVisitor drawer = new ScatterplotDrawingRowVisitor(
-                      columnIndex_x, columnIndex_y, min_x, max_x, min_y, max_y, 
-                      config.size, config.dim_x, config.dim_y, config.rotation, config.dot, config.getColor()
-                    );
+                            columnIndex_x, columnIndex_y, min_x, max_x, min_y, max_y,
+                            config.size, config.dim_x, config.dim_y, config.rotation, config.dot, config.getColor());
                     filteredRecords.accept(project, drawer);
-                 
+
                     try {
                         image = serializeImage(drawer.getImage());
                     } catch (IOException e) {
@@ -478,55 +477,54 @@ public class ScatterplotFacet implements Facet {
             }
         }
     }
-    
+
     protected void retrieveDataFromBinIndices(NumericBinIndex index_x, NumericBinIndex index_y) {
         min_x = index_x.getMin();
         max_x = index_x.getMax();
-                    
+
         min_y = index_y.getMin();
         max_y = index_y.getMax();
     }
-    
+
     public static String serializeImage(RenderedImage image) throws IOException {
         ByteArrayOutputStream output = new ByteArrayOutputStream(4096);
         ImageIO.write(image, "png", output);
         output.close();
         String encoded = Base64.encodeBase64String(output.toByteArray());
-        String url =  "data:image/png;base64," + encoded;
+        String url = "data:image/png;base64," + encoded;
         return url;
     }
-    
+
     public static int getAxisDim(String type) {
         return ("log".equals(type.toLowerCase())) ? LOG : LIN;
     }
-   
-    
+
     public static NumericBinIndex getBinIndex(Project project, Column column, Evaluable eval, String expression) {
         return getBinIndex(project, column, eval, expression, "row-based");
     }
-    
+
     public static NumericBinIndex getBinIndex(Project project, Column column, Evaluable eval, String expression, String mode) {
         String key = "numeric-bin:" + mode + ":" + expression;
         if (eval == null) {
             try {
                 eval = MetaParser.parse(expression);
             } catch (ParsingException e) {
-                logger.warn("Error parsing expression",e);
+                logger.warn("Error parsing expression", e);
             }
         }
         NumericBinIndex index = (NumericBinIndex) column.getPrecompute(key);
         if (index == null) {
-            index = "row-based".equals(mode) ? 
-                    new NumericBinRowIndex(project, new ExpressionBasedRowEvaluable(column.getName(), column.getCellIndex(), eval)) :
-                        new NumericBinRecordIndex(project, new ExpressionBasedRowEvaluable(column.getName(), column.getCellIndex(), eval));
+            index = "row-based".equals(mode)
+                    ? new NumericBinRowIndex(project, new ExpressionBasedRowEvaluable(column.getName(), column.getCellIndex(), eval))
+                    : new NumericBinRecordIndex(project, new ExpressionBasedRowEvaluable(column.getName(), column.getCellIndex(), eval));
 
-                    column.setPrecompute(key, index);
+            column.setPrecompute(key, index);
         }
         return index;
     }
-    
+
     private static double s_rotateScale = 1 / Math.sqrt(2.0);
-    
+
     public static AffineTransform createRotationMatrix(int rotation, double l) {
         if (rotation == ScatterplotFacet.ROTATE_CW) {
             AffineTransform t = AffineTransform.getTranslateInstance(0, l / 2);
@@ -542,15 +540,15 @@ public class ScatterplotFacet implements Facet {
             return null;
         }
     }
-    
+
     public static Point2D.Double translateCoordinates(
-            Point2D.Double p, 
+            Point2D.Double p,
             double min_x, double max_x, double min_y, double max_y,
             int dim_x, int dim_y, double l, AffineTransform t) {
-        
+
         double x = p.x;
         double y = p.y;
-        
+
         double relative_x = x - min_x;
         double range_x = max_x - min_x;
         if (dim_x == ScatterplotFacet.LOG) {
@@ -566,14 +564,14 @@ public class ScatterplotFacet implements Facet {
         } else {
             y = relative_y * l / range_y;
         }
-        
+
         p.x = x;
         p.y = y;
         if (t != null) {
             t.transform(p, p);
         }
-        
+
         return p;
     }
-    
+
 }
