@@ -43,8 +43,8 @@ import com.fasterxml.jackson.databind.JsonNode;
 import com.google.refine.util.JSONUtilities;
 
 public class SqlInsertBuilder {
-    
-    private  static final Logger logger = LoggerFactory.getLogger("SQLInsertBuilder");
+
+    private static final Logger logger = LoggerFactory.getLogger("SQLInsertBuilder");
 
     private String table;
 
@@ -54,134 +54,135 @@ public class SqlInsertBuilder {
 
     private JsonNode options;
 
-    
     /**
      * 
      * @param table
      * @param columns
      * @param rows
      * @param sqlOptions
-     * @param sqlErrors 
      */
-    public SqlInsertBuilder(String table, List<String> columns, List<ArrayList<SqlData>> rows, JsonNode sqlOptions
-            ) {
+    public SqlInsertBuilder(String table, List<String> columns, List<ArrayList<SqlData>> rows, JsonNode sqlOptions) {
         this.table = table;
         this.columns = columns;
         this.sqlDataList = rows;
         this.options = sqlOptions;
-        //logger.info("Column Size:{}", columns.size());
-    
+        // logger.info("Column Size:{}", columns.size());
+
     }
 
-   /**
-    * Get Insert Sql
-    * @return
-    */
-    public String getInsertSQL(){
-        if(logger.isDebugEnabled()) {
+    /**
+     * Get Insert Sql
+     * 
+     * @return
+     */
+    public String getInsertSQL() {
+        if (logger.isDebugEnabled()) {
             logger.debug("Insert SQL with columns: {}", columns);
         }
-        
+
         List<JsonNode> colOptionArray = options == null ? null : JSONUtilities.getArray(options, "columns");
         Map<String, JsonNode> colOptionsMap = new HashMap<>();
-        if(colOptionArray != null) {
-            colOptionArray.forEach(json -> { 
+        if (colOptionArray != null) {
+            colOptionArray.forEach(json -> {
                 colOptionsMap.put(JSONUtilities.getString(json, "name", null), json);
             });
         }
-      
+
         boolean nullValueNull = options == null ? true : JSONUtilities.getBoolean(options, "convertNulltoEmptyString", true);
-               
+
         StringBuffer values = new StringBuffer();
-       
+
         int idx = 0;
-        for(ArrayList<SqlData> sqlRow : sqlDataList) {
+        for (ArrayList<SqlData> sqlRow : sqlDataList) {
             StringBuilder rowValue = new StringBuilder();
-            
-            //int fieldCount = 0;
-            for(SqlData val : sqlRow) {
-             
+
+            // int fieldCount = 0;
+            for (SqlData val : sqlRow) {
+
                 JsonNode jsonOb = colOptionsMap.get(val.getColumnName());
                 String type = JSONUtilities.getString(jsonOb, "type", null);
-                
+
                 String defaultValue = JSONUtilities.getString(jsonOb, "defaultValue", null);
-              
-                boolean allowNullChkBox = JSONUtilities.getBoolean(jsonOb, "defaultValue", true);;
-                if(type == null) {
+
+                boolean allowNullChkBox = JSONUtilities.getBoolean(jsonOb, "defaultValue", true);
+                ;
+                if (type == null) {
                     type = SqlData.SQL_TYPE_VARCHAR;
                 }
-                //Character Types
-                if(type.equals(SqlData.SQL_TYPE_VARCHAR) || type.equals(SqlData.SQL_TYPE_CHAR) || type.equals(SqlData.SQL_TYPE_TEXT)) {
+                // Character Types
+                if (type.equals(SqlData.SQL_TYPE_VARCHAR) || type.equals(SqlData.SQL_TYPE_CHAR) || type.equals(SqlData.SQL_TYPE_TEXT)) {
+
+                    if ((val.getText() == null || val.getText().isEmpty())) {
 
-                    if((val.getText() == null || val.getText().isEmpty()) ) {
-                      
                         handleNullField(allowNullChkBox, defaultValue, nullValueNull, val.getColumnName(), rowValue, true);
-                        
-                    }else {
-                        rowValue.append("'" + val.getText().replace("'","''") + "'"); 
-                        
+
+                    } else {
+                        rowValue.append("'" + val.getText().replace("'", "''") + "'");
+
                     }
-                 
-                }else if(type.equals(SqlData.SQL_TYPE_INT) || type.equals(SqlData.SQL_TYPE_INTEGER) || type.equals(SqlData.SQL_TYPE_NUMERIC)) {//Numeric Types : INT, NUMERIC
-                    
-                    if((val.getText() == null || val.getText().isEmpty())) {
-                        
+
+                } else if (type.equals(SqlData.SQL_TYPE_INT) || type.equals(SqlData.SQL_TYPE_INTEGER)
+                        || type.equals(SqlData.SQL_TYPE_NUMERIC)) {// Numeric Types : INT, NUMERIC
+
+                    if ((val.getText() == null || val.getText().isEmpty())) {
+
                         handleNullField(allowNullChkBox, defaultValue, nullValueNull, val.getColumnName(), rowValue, false);
-                 
-                    }else {//value not null
-                        
-                        if(type.equals(SqlData.SQL_TYPE_NUMERIC)) {//test if number is numeric (decimal(p,s) number is valid)
-                           
-                            if(!NumberUtils.isCreatable(val.getText())){
+
+                    } else {// value not null
+
+                        if (type.equals(SqlData.SQL_TYPE_NUMERIC)) {// test if number is numeric (decimal(p,s) number is
+                                                                    // valid)
+
+                            if (!NumberUtils.isCreatable(val.getText())) {
                                 throw new SqlExporterException(
                                         val.getText() + " is not compatible with column type :" + type);
                             }
-                        }else {
-                            
-                            try { //number should be an integer
+                        } else {
+
+                            try { // number should be an integer
                                 Integer.parseInt(val.getText());
                             } catch (NumberFormatException nfe) {
                                 throw new SqlExporterException(
                                         val.getText() + " is not compatible with column type :" + type);
                             }
-                            
+
                         }
-                       
+
                         rowValue.append(val.getText());
-                       
+
                     }
-                    
-                }else if(type.equals(SqlData.SQL_TYPE_DATE) || type.equals(SqlData.SQL_TYPE_TIMESTAMP)) {
-                    if((val.getText() == null || val.getText().isEmpty())) {
+
+                } else if (type.equals(SqlData.SQL_TYPE_DATE) || type.equals(SqlData.SQL_TYPE_TIMESTAMP)) {
+                    if ((val.getText() == null || val.getText().isEmpty())) {
                         handleNullField(allowNullChkBox, defaultValue, nullValueNull, val.getColumnName(), rowValue, true);
-                    }else {
-                        rowValue.append("'" + val.getText() + "'"); 
+                    } else {
+                        rowValue.append("'" + val.getText() + "'");
                     }
                 }
-                
+
                 rowValue.append(",");
-            
+
             }
-       
+
             idx++;
             String rowValString = rowValue.toString();
 //            logger.info("rowValString::" + rowValString);
             rowValString = rowValString.substring(0, rowValString.length() - 1);
-            
+
             values.append("( ");
             values.append(rowValString);
             values.append(" )");
-            if(idx < sqlDataList.size()) {
-                values.append(","); 
+            if (idx < sqlDataList.size()) {
+                values.append(",");
             }
             values.append("\n");
-           
+
         }
 
         boolean trimColNames = options == null ? false : JSONUtilities.getBoolean(options, "trimColumnNames", false);
         String colNamesWithSep = columns.stream().map(col -> col.replaceAll("[^a-zA-Z0-9_]", "_")).collect(Collectors.joining(","));
-        if(!trimColNames) {
-           colNamesWithSep = columns.stream().collect(Collectors.joining(","));  
+        if (!trimColNames) {
+            colNamesWithSep = columns.stream().collect(Collectors.joining(","));
         }
 
         String valuesString = values.toString();
@@ -194,9 +195,9 @@ public class SqlInsertBuilder {
         sql.append(colNamesWithSep);
         sql.append(") VALUES ").append("\n");
         sql.append(valuesString);
-        
+
         String sqlString = sql.toString();
-        if(logger.isDebugEnabled()) {
+        if (logger.isDebugEnabled()) {
             logger.debug("Insert Statement Generated Successfully...{}", sqlString);
         }
         return sqlString;
@@ -210,50 +211,47 @@ public class SqlInsertBuilder {
      * @param col
      * @param rowValue
      * @param quote
-     * @param fieldCount
      */
     public void handleNullField(
-            boolean allowNullChkBox, 
-            String defaultValue, 
-            boolean nullValueNull, 
+            boolean allowNullChkBox,
+            String defaultValue,
+            boolean nullValueNull,
             String col,
-            StringBuilder rowValue, 
-            boolean quote
-            ) {
+            StringBuilder rowValue,
+            boolean quote) {
 
-        if(allowNullChkBox) {//cell nullable
-            if(defaultValue != null && !defaultValue.isEmpty()) {
-                if(quote) {
-                    rowValue.append("'" + defaultValue + "'");  
-                }else {
+        if (allowNullChkBox) {// cell nullable
+            if (defaultValue != null && !defaultValue.isEmpty()) {
+                if (quote) {
+                    rowValue.append("'" + defaultValue + "'");
+                } else {
                     rowValue.append(defaultValue);
-                } 
-               
-            }else {
-                if(nullValueNull) {
-                    rowValue.append("null"); 
-                   
-                }else {
-                    throw new SqlExporterException("Null value not allowed for Field :" + col); 
                 }
-                
+
+            } else {
+                if (nullValueNull) {
+                    rowValue.append("null");
+
+                } else {
+                    throw new SqlExporterException("Null value not allowed for Field :" + col);
+                }
+
             }
-            
-        }else {
-            if(defaultValue != null && !defaultValue.isEmpty()) {
-                if(quote) {
-                    rowValue.append("'" + defaultValue + "'"); 
-                }else {
+
+        } else {
+            if (defaultValue != null && !defaultValue.isEmpty()) {
+                if (quote) {
+                    rowValue.append("'" + defaultValue + "'");
+                } else {
                     rowValue.append(defaultValue);
-                }    
-               
-            }else {
+                }
+
+            } else {
                 throw new SqlExporterException("Null value not allowed for Field :" + col);
             }
-           
+
         }
-        
+
     }
-    
- 
+
 }
