@@ -45,14 +45,16 @@ import java.util.TimeZone;
 
 import com.google.refine.expr.EvalError;
 import com.google.refine.grel.ControlFunctionRegistry;
+import com.google.refine.grel.EvalErrorMessage;
 import com.google.refine.grel.Function;
+import com.google.refine.grel.FunctionDescription;
 
 public class DatePart implements Function {
 
     @Override
     public Object call(Properties bindings, Object[] args) {
-        if (args.length == 2 && 
-                args[0] != null && (args[0] instanceof Calendar || args[0] instanceof Date || args[0] instanceof OffsetDateTime) && 
+        if (args.length == 2 &&
+                args[0] != null && (args[0] instanceof Calendar || args[0] instanceof Date || args[0] instanceof OffsetDateTime) &&
                 args[1] != null && args[1] instanceof String) {
             String part = (String) args[1];
             if (args[0] instanceof Calendar) {
@@ -65,13 +67,14 @@ public class DatePart implements Function {
                 return getPart((OffsetDateTime) args[0], part);
             }
         }
-        return new EvalError(ControlFunctionRegistry.getFunctionName(this) + " expects a date and a string");
+        return new EvalError(EvalErrorMessage.expects_date_and_string(ControlFunctionRegistry.getFunctionName(this)));
     }
-    
+
     private Object getPart(OffsetDateTime offsetDateTime, String part) {
         if ("hours".equals(part) || "hour".equals(part) || "h".equals(part)) {
             return offsetDateTime.getHour();
-        } else if ("minutes".equals(part) || "minute".equals(part) || "min".equals(part)) { // avoid 'm' to avoid confusion with month
+        } else if ("minutes".equals(part) || "minute".equals(part) || "min".equals(part)) { // avoid 'm' to avoid
+                                                                                            // confusion with month
             return offsetDateTime.getMinute();
         } else if ("seconds".equals(part) || "sec".equals(part) || "s".equals(part)) {
             return offsetDateTime.getSecond();
@@ -90,10 +93,10 @@ public class DatePart implements Function {
             return offsetDateTime.getDayOfMonth();
         } else if ("weekday".equals(part)) {
             return offsetDateTime.getDayOfWeek().name();
-        } else if ("time".equals(part)) {       // get Time In Millis
+        } else if ("time".equals(part)) { // get Time In Millis
             return offsetDateTime.toInstant().toEpochMilli();
         } else {
-            return new EvalError("Date unit '" + part + "' not recognized.");
+            return new EvalError(EvalErrorMessage.unrecognized_date_part(part));
         }
     }
 
@@ -103,18 +106,19 @@ public class DatePart implements Function {
         int minDays = 1;
         WeekFields week = WeekFields.of(firstDayOfWeek, minDays);
         TemporalField womField = week.weekOfMonth();
-        
+
         return date.get(womField);
     }
-    
+
     static private String[] s_daysOfWeek = new String[] {
-        "Saturday", "Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"
+            "Saturday", "Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"
     };
 
     private Object getPart(Calendar c, String part) {
         if ("hours".equals(part) || "hour".equals(part) || "h".equals(part)) {
             return c.get(Calendar.HOUR_OF_DAY);
-        } else if ("minutes".equals(part) || "minute".equals(part) || "min".equals(part)) { // avoid 'm' to avoid confusion with month
+        } else if ("minutes".equals(part) || "minute".equals(part) || "min".equals(part)) { // avoid 'm' to avoid
+                                                                                            // confusion with month
             return c.get(Calendar.MINUTE);
         } else if ("seconds".equals(part) || "sec".equals(part) || "s".equals(part)) {
             return c.get(Calendar.SECOND);
@@ -133,20 +137,20 @@ public class DatePart implements Function {
         } else if ("time".equals(part)) {
             return c.getTimeInMillis();
         } else {
-            return new EvalError("Date unit '" + part + "' not recognized.");
+            return new EvalError(EvalErrorMessage.unrecognized_date_part(part));
         }
     }
-    
+
     @Override
     public String getDescription() {
-    	return "Returns part of a date. The data type returned depends on the unit. See https://docs.openrefine.org/manual/grelfunctions/#datepartd-s-timeunit, https://docs.openrefine.org/manual/grelfunctions#date-functions for a table. ";
+        return FunctionDescription.date_part();
     }
-    
+
     @Override
     public String getParams() {
         return "date d, string timeUnit";
     }
-    
+
     @Override
     public String getReturns() {
         return "date";
