@@ -39,7 +39,9 @@ import com.google.refine.expr.EvalError;
 import com.google.refine.expr.functions.Type;
 import com.google.refine.expr.functions.xml.ParseXml;
 import com.google.refine.grel.ControlFunctionRegistry;
+import com.google.refine.grel.EvalErrorMessage;
 import com.google.refine.grel.Function;
+import com.google.refine.grel.FunctionDescription;
 
 public class ParseHtml implements Function {
 
@@ -48,26 +50,25 @@ public class ParseHtml implements Function {
         if (args.length == 1) {
             Object o1 = args[0];
             if (o1 != null && o1 instanceof String) {
-                return new ParseXml().call(bindings,args,"html");
+                return new ParseXml().call(bindings, args, "html");
             }
         }
-        return new EvalError(ControlFunctionRegistry.getFunctionName(this) + " expects a single String as an argument");
+        // argument");
+        return new EvalError(EvalErrorMessage.expects_single_string_as_arg(ControlFunctionRegistry.getFunctionName(this)));
     }
 
-
     @Override
     public String getDescription() {
-        return "Given a cell full of HTML-formatted text, parseHtml() simplifies HTML tags (such as by removing ' /' at the end of self-closing tags), closes any unclosed tags, and inserts linebreaks and indents for cleaner code. A cell cannot store the output of parseHtml() unless you convert it with toString(): for example, value.parseHtml().toString().";
+        return FunctionDescription.html_parse_html();
     }
-    
+
     @Override
     public String getParams() {
         return "string s";
     }
-    
+
     @Override
     public String getReturns() {
         return "HTML object";
     }
 }
-
