@@ -37,7 +37,9 @@ import java.util.Properties;
 
 import com.google.refine.expr.EvalError;
 import com.google.refine.grel.ControlFunctionRegistry;
+import com.google.refine.grel.EvalErrorMessage;
 import com.google.refine.grel.Function;
+import com.google.refine.grel.FunctionDescription;
 
 public class ATan2 implements Function {
 
@@ -45,23 +47,23 @@ public class ATan2 implements Function {
     public Object call(Properties bindings, Object[] args) {
         if (args.length == 2 && args[0] instanceof Number
                 && args[1] instanceof Number) {
-            return Math.atan2(((Number) args[0]).doubleValue(),((Number) args[1]).doubleValue());
+            return Math.atan2(((Number) args[0]).doubleValue(), ((Number) args[1]).doubleValue());
         }
-        return new EvalError(ControlFunctionRegistry.getFunctionName(this) + " expects a number");
+        return new EvalError(EvalErrorMessage.expects_one_number(ControlFunctionRegistry.getFunctionName(this)));
     }
 
     @Override
     public String getDescription() {
-        return "Converts rectangular coordinates (n1, n2) to polar (r, theta). Returns number theta.";
+        return FunctionDescription.math_atan2();
     }
-    
+
     @Override
     public String getParams() {
         return "number n1, number n2";
     }
-    
+
     @Override
     public String getReturns() {
         return "number theta";
     }
-}
\ No newline at end of file
+}
