@@ -39,7 +39,9 @@ import java.util.concurrent.ThreadLocalRandom;
 
 import com.google.refine.expr.EvalError;
 import com.google.refine.grel.ControlFunctionRegistry;
+import com.google.refine.grel.EvalErrorMessage;
 import com.google.refine.grel.Function;
+import com.google.refine.grel.FunctionDescription;
 
 public class RandomNumber implements Function {
 
@@ -51,34 +53,35 @@ public class RandomNumber implements Function {
         } else if (args.length == 2) {
             // Return a double in the interval lowerBound <= x < upperBound
             if (args[0] instanceof Number && args[1] instanceof Number
-                    && ((Number) args[0]).intValue()<((Number) args[1]).intValue()) {
+                    && ((Number) args[0]).intValue() < ((Number) args[1]).intValue()) {
 
                 // check if arguments are long
                 if (args[0] instanceof Long && args[1] instanceof Long) {
                     // return a long
-                    return ThreadLocalRandom.current().nextLong(((Number) args[0]).longValue(), ((Number) args[1]).longValue()+1);
+                    return ThreadLocalRandom.current().nextLong(((Number) args[0]).longValue(), ((Number) args[1]).longValue() + 1);
                 } else {
                     // return a double
                     return ThreadLocalRandom.current().nextDouble(((Number) args[0]).doubleValue(), ((Number) args[1]).doubleValue());
                 }
             }
         }
-        return new EvalError(ControlFunctionRegistry.getFunctionName(this) + " expects no arguments or two numbers, the first must be less than the second");
+        // the first must be less than the second");
+        return new EvalError(EvalErrorMessage.expects_no_arg_or_two_numbers_asc(ControlFunctionRegistry.getFunctionName(this)));
     }
 
     @Override
     public String getDescription() {
-        return "Returns a random integer in the interval between the lower and upper bounds (inclusively). Will output a different random number in each cell in a column.";
+        return FunctionDescription.math_random_number();
     }
-    
+
     @Override
     public String getParams() {
         return "number lowerBound, number upperBound";
     }
-    
+
     @Override
     public String getReturns() {
         return "number";
     }
-    
-}
\ No newline at end of file
+
+}
