@@ -36,6 +36,8 @@ package com.google.refine.expr.functions.xml;
 import java.util.Properties;
 
 import com.google.refine.expr.functions.Type;
+import com.google.refine.grel.EvalErrorMessage;
+import com.google.refine.grel.FunctionDescription;
 import org.jsoup.Jsoup;
 import org.jsoup.parser.Parser;
 
@@ -47,9 +49,9 @@ public class ParseXml implements Function {
 
     @Override
     public Object call(Properties bindings, Object[] args) {
-        return call(bindings,args,"xml");
+        return call(bindings, args, "xml");
     }
-    
+
     public Object call(Properties bindings, Object[] args, String mode) {
         if (args.length == 1) {
             Object o1 = args[0];
@@ -57,29 +59,29 @@ public class ParseXml implements Function {
                 if (mode.equals("html")) {
                     return Jsoup.parse(o1.toString());
                 } else if (mode.equals("xml")) {
-                    return Jsoup.parse(o1.toString(), "",Parser.xmlParser());
+                    return Jsoup.parse(o1.toString(), "", Parser.xmlParser());
                 } else {
-                    return new EvalError(ControlFunctionRegistry.getFunctionName(this) + " unable to identify which parser to use");
+                    // parser to use");
+                    return new EvalError(EvalErrorMessage.unable_to_identify_parser(ControlFunctionRegistry.getFunctionName(this)));
                 }
             }
         }
-        return new EvalError(ControlFunctionRegistry.getFunctionName(this) + " expects a single String as an argument");
+        // argument");
+        return new EvalError(EvalErrorMessage.expects_one_string(ControlFunctionRegistry.getFunctionName(this)));
     }
 
-
     @Override
     public String getDescription() {
-    	return "Given a cell full of XML-formatted text, parseXml() returns a full XML document and adds any missing closing tags.";
+        return FunctionDescription.xml_parsexml();
     }
-    
+
     @Override
     public String getParams() {
         return "string s";
     }
-    
+
     @Override
     public String getReturns() {
-    	return "XML object";
+        return "XML object";
     }
 }
-
