@@ -41,11 +41,13 @@ import java.io.InputStream;
 import java.io.OutputStream;
 import java.util.HashMap;
 import java.util.List;
+import java.util.Locale;
 import java.util.Map.Entry;
 import java.util.Set;
 import java.util.zip.GZIPInputStream;
 import java.util.zip.GZIPOutputStream;
 
+import com.google.refine.util.LocaleUtils;
 import org.apache.commons.compress.archivers.tar.TarArchiveEntry;
 import org.apache.commons.compress.archivers.tar.TarArchiveInputStream;
 import org.apache.commons.compress.archivers.tar.TarArchiveOutputStream;
@@ -63,11 +65,11 @@ import com.google.refine.preference.PreferenceStore;
 import com.google.refine.preference.TopList;
 import com.google.refine.util.ParsingUtilities;
 
+public class FileProjectManager extends ProjectManager {
 
-public class FileProjectManager extends ProjectManager  {
     final static protected String PROJECT_DIR_SUFFIX = ".project";
 
-    protected File                       _workspaceDir;
+    protected File _workspaceDir;
 
     protected static boolean projectRemoved = false;
 
@@ -113,8 +115,8 @@ public class FileProjectManager extends ProjectManager  {
     }
 
     /**
-     * Import an external project that has been received as a .tar file, expanded, and
-     * copied into our workspace directory.
+     * Import an external project that has been received as a .tar file, expanded, and copied into our workspace
+     * directory.
      *
      * @param projectID
      */
@@ -125,20 +127,20 @@ public class FileProjectManager extends ProjectManager  {
             if (metadata == null) {
                 metadata = ProjectMetadataUtilities.recover(getProjectDir(projectID), projectID);
             }
-            
+
             if (metadata != null) {
                 _projectsMetadata.put(projectID, metadata);
                 if (_projectsTags == null) {
                     _projectsTags = new HashMap<String, Integer>();
                 }
-                
+
                 if (metadata != null && metadata.getTags() != null) {
                     for (String tag : metadata.getTags()) {
-                      if (_projectsTags.containsKey(tag)) {
-                        _projectsTags.put(tag, _projectsTags.get(tag) + 1);
-                      } else {
-                        _projectsTags.put(tag, 1);
-                      }
+                        if (_projectsTags.containsKey(tag)) {
+                            _projectsTags.put(tag, _projectsTags.get(tag) + 1);
+                        } else {
+                            _projectsTags.put(tag, 1);
+                        }
                     }
                 }
                 return true;
@@ -167,6 +169,9 @@ public class FileProjectManager extends ProjectManager  {
 
         while ((tarEntry = tin.getNextTarEntry()) != null) {
             File destEntry = new File(destDir, tarEntry.getName());
+            if (!destEntry.toPath().normalize().startsWith(destDir.toPath().normalize())) {
+                throw new IllegalArgumentException("Zip archives with files escaping their root directory are not allowed.");
+            }
             File parent = destEntry.getParentFile();
 
             if (!parent.exists()) {
@@ -184,7 +189,7 @@ public class FileProjectManager extends ProjectManager  {
                 }
             }
         }
-        
+
         tin.close();
     }
 
@@ -194,11 +199,11 @@ public class FileProjectManager extends ProjectManager  {
         this.tarDir("", dir, tos);
     }
 
-    protected void tarDir(String relative, File dir, TarArchiveOutputStream tos) throws IOException{
+    protected void tarDir(String relative, File dir, TarArchiveOutputStream tos) throws IOException {
         File[] files = dir.listFiles();
         if (files == null) return;
         for (File file : files) {
-        	if (file == null) continue;
+            if (file == null) continue;
             if (!file.isHidden()) {
                 String path = relative + file.getName();
 
@@ -229,7 +234,7 @@ public class FileProjectManager extends ProjectManager  {
             byte[] buf = new byte[buffersize];
             int count;
 
-            while((count = fis.read(buf, 0, buffersize)) != -1) {
+            while ((count = fis.read(buf, 0, buffersize)) != -1) {
                 os.write(buf, 0, count);
             }
         } finally {
@@ -244,7 +249,7 @@ public class FileProjectManager extends ProjectManager  {
     }
 
     @Override
-    protected void saveProject(Project project) throws IOException{
+    protected void saveProject(Project project) throws IOException {
         ProjectUtilities.save(project);
     }
 
@@ -253,10 +258,9 @@ public class FileProjectManager extends ProjectManager  {
         return ProjectUtilities.load(getProjectDir(id), id);
     }
 
-
     /**
-     * Save the workspace's data out to file in a safe way: save to a temporary file first
-     * and rename it to the real file.
+     * Save the workspace's data out to file in a safe way: save to a temporary file first and rename it to the real
+     * file.
      */
     @Override
     protected void saveWorkspace() {
@@ -285,7 +289,7 @@ public class FileProjectManager extends ProjectManager  {
             if (oldFile.exists()) {
                 oldFile.delete();
             }
-            
+
             if (file.exists()) {
                 file.renameTo(oldFile);
             }
@@ -295,15 +299,15 @@ public class FileProjectManager extends ProjectManager  {
             logger.info("Saved workspace");
         }
     }
-    
+
     protected boolean saveNeeded() {
         boolean projectSaveNeeded = _projectsMetadata.entrySet().stream()
                 .anyMatch(e -> e.getValue() != null && e.getValue().isDirty());
         return projectSaveNeeded || _preferenceStore.isDirty() || projectRemoved;
     }
-    
+
     protected void saveProjectMetadata() throws IOException {
-        for(Entry<Long,ProjectMetadata> entry : _projectsMetadata.entrySet()) {
+        for (Entry<Long, ProjectMetadata> entry : _projectsMetadata.entrySet()) {
             ProjectMetadata metadata = entry.getValue();
             if (metadata != null && metadata.isDirty()) {
                 ProjectMetadataUtilities.save(metadata, getProjectDir(entry.getKey()));
@@ -324,8 +328,6 @@ public class FileProjectManager extends ProjectManager  {
         return saveWasNeeded;
     }
 
-
-
     @Override
     public void deleteProject(long projectID) {
         synchronized (this) {
@@ -341,10 +343,10 @@ public class FileProjectManager extends ProjectManager  {
     }
 
     static protected void deleteDir(File dir) {
-    	File[] files = dir.listFiles();
-    	if (files == null) return;
+        File[] files = dir.listFiles();
+        if (files == null) return;
         for (File file : files) {
-        	if (file == null) continue;
+            if (file == null) continue;
             if (file.isDirectory()) {
                 deleteDir(file);
             } else {
@@ -366,7 +368,7 @@ public class FileProjectManager extends ProjectManager  {
         }
         logger.error("Failed to load workspace from any attempted alternatives.");
     }
-    
+
     protected boolean loadFromFile(File file) {
         logger.info("Loading workspace: {}", file.getAbsolutePath());
 
@@ -375,12 +377,15 @@ public class FileProjectManager extends ProjectManager  {
         boolean found = false;
 
         if (file.exists() || file.canRead()) {
-	        try {
-	        	ParsingUtilities.mapper.readerForUpdating(this).readValue(file);
-	            found = true;
-	        } catch(IOException e) {
-	        	logger.warn(e.toString());
-	        }
+            try {
+                ParsingUtilities.mapper.readerForUpdating(this).readValue(file);
+
+                LocaleUtils.setLocale((String) this.getPreferenceStore().get("userLang"));
+
+                found = true;
+            } catch (IOException e) {
+                logger.warn(e.toString());
+            }
         }
 
         return found;
@@ -389,9 +394,9 @@ public class FileProjectManager extends ProjectManager  {
     protected void recover() {
         boolean recovered = false;
         File[] files = _workspaceDir.listFiles();
-    	if (files == null) return;
+        if (files == null) return;
         for (File file : files) {
-        	if (file == null) continue;
+            if (file == null) continue;
             if (file.isDirectory() && !file.isHidden()) {
                 String dirName = file.getName();
                 if (file.getName().endsWith(PROJECT_DIR_SUFFIX)) {
@@ -405,7 +410,7 @@ public class FileProjectManager extends ProjectManager  {
 
                     if (id > 0 && !_projectsMetadata.containsKey(id)) {
                         if (loadProjectMetadata(id)) {
-                            logger.info("Recovered project named " 
+                            logger.info("Recovered project named "
                                     + getProjectMetadata(id).getName()
                                     + " in directory " + dirName);
                             recovered = true;
@@ -424,10 +429,10 @@ public class FileProjectManager extends ProjectManager  {
     }
 
     @Override
-    public HistoryEntryManager getHistoryEntryManager(){
+    public HistoryEntryManager getHistoryEntryManager() {
         return new FileHistoryEntryManager();
     }
-    
+
     public static void gzipTarToOutputStream(Project project, OutputStream os) throws IOException {
         GZIPOutputStream gos = new GZIPOutputStream(os);
         TarArchiveOutputStream tos = new TarArchiveOutputStream(gos);
@@ -438,47 +443,47 @@ public class FileProjectManager extends ProjectManager  {
             gos.close();
         }
     }
-    
+
     @JsonProperty("projectIDs")
     public Set<Long> getProjectIds() {
         return _projectsMetadata.keySet();
     }
-    
+
     @JsonProperty("projectIDs")
     protected void loadProjects(List<Long> projectIDs) {
         for (Long id : projectIDs) {
 
             File projectDir = getProjectDir(id);
             ProjectMetadata metadata = ProjectMetadataUtilities.load(projectDir);
-            
+
             mergeEmptyUserMetadata(metadata);
 
             _projectsMetadata.put(id, metadata);
-            
+
             if (metadata != null && metadata.getTags() != null) {
                 for (String tag : metadata.getTags()) {
-                  if (_projectsTags.containsKey(tag)) {
-                    _projectsTags.put(tag, _projectsTags.get(tag) + 1);
-                  } else {
-                    _projectsTags.put(tag, 1);
-                  }
+                    if (_projectsTags.containsKey(tag)) {
+                        _projectsTags.put(tag, _projectsTags.get(tag) + 1);
+                    } else {
+                        _projectsTags.put(tag, 1);
+                    }
                 }
             }
         }
     }
-    
+
     @JsonProperty("preferences")
     protected void setPreferences(PreferenceStore preferences) {
-    	if(preferences != null) {
-    		_preferenceStore = preferences;
-    	}
+        if (preferences != null) {
+            _preferenceStore = preferences;
+        }
     }
-    
+
     // backwards compatibility
     @JsonProperty("expressions")
-	protected void setExpressions(TopList newExpressions) {
-    	if (newExpressions != null) {
-    		_preferenceStore.put("scripting.expressions", newExpressions);
-    	}
+    protected void setExpressions(TopList newExpressions) {
+        if (newExpressions != null) {
+            _preferenceStore.put("scripting.expressions", newExpressions);
+        }
     }
 }
