@@ -70,40 +70,36 @@ import com.google.refine.util.HttpClient;
 import com.google.refine.util.ParsingUtilities;
 
 public class StandardReconConfig extends ReconConfig {
+
     final static Logger logger = LoggerFactory.getLogger("refine-standard-recon");
 
     private static final String DEFAULT_SCHEMA_SPACE = "http://localhost/schema";
     private static final String DEFAULT_IDENTIFIER_SPACE = "http://localhost/identifier";
 
-    static public class ColumnDetail  {
+    static public class ColumnDetail {
+
         @JsonProperty("column")
         final public String columnName;
         @JsonProperty("propertyName")
         final public String propertyName;
         @JsonProperty("propertyID")
         final public String propertyID;
-        
+
         /**
-         * Unfortunately the format of ColumnDetail
-         * is inconsistent in the UI and the backend
-         * so we need to support two deserialization formats.
-         * See the tests for that.
+         * Unfortunately the format of ColumnDetail is inconsistent in the UI and the backend so we need to support two
+         * deserialization formats. See the tests for that.
          */
         @JsonCreator
         public ColumnDetail(
-                @JsonProperty("column")
-                String columnName,
-                @JsonProperty("propertyName")
-                String propertyName,
-                @JsonProperty("propertyID")
-                String propertyID,
-                @JsonProperty("property")
-                ReconType property) {
+                @JsonProperty("column") String columnName,
+                @JsonProperty("propertyName") String propertyName,
+                @JsonProperty("propertyID") String propertyID,
+                @JsonProperty("property") ReconType property) {
             this.columnName = columnName;
             this.propertyName = property == null ? propertyName : property.name;
             this.propertyID = property == null ? propertyID : property.id;
         }
-        
+
         @Override
         public String toString() {
             try {
@@ -113,15 +109,16 @@ public class StandardReconConfig extends ReconConfig {
             }
         }
     }
-    
+
     static public StandardReconConfig reconstruct(String json) throws IOException {
         return ParsingUtilities.mapper.readValue(json, StandardReconConfig.class);
     }
-    
+
     static protected class StandardReconJob extends ReconJob {
+
         String text;
         String code;
-        
+
         @Override
         public int getKey() {
             return code.hashCode();
@@ -134,18 +131,18 @@ public class StandardReconConfig extends ReconConfig {
     }
 
     @JsonProperty("service")
-    final public String     service;
+    final public String service;
     @JsonProperty("identifierSpace")
-    final public String     identifierSpace;
+    final public String identifierSpace;
     @JsonProperty("schemaSpace")
-    final public String     schemaSpace;
-    
+    final public String schemaSpace;
+
     @JsonIgnore
-    final public String     typeID;
+    final public String typeID;
     @JsonIgnore
-    final public String     typeName;
+    final public String typeName;
     @JsonProperty("autoMatch")
-    final public boolean    autoMatch;
+    final public boolean autoMatch;
     @JsonProperty("columnDetails")
     final public List<ColumnDetail> columnDetails;
     @JsonProperty("limit")
@@ -156,20 +153,13 @@ public class StandardReconConfig extends ReconConfig {
 
     @JsonCreator
     public StandardReconConfig(
-            @JsonProperty("service")
-            String service,
-            @JsonProperty("identifierSpace")
-            String identifierSpace,
-            @JsonProperty("schemaSpace")
-            String schemaSpace,
-            @JsonProperty("type")
-            ReconType type,
-            @JsonProperty("autoMatch")
-            boolean autoMatch,
-            @JsonProperty("columnDetails")
-            List<ColumnDetail> columnDetails,
-            @JsonProperty("limit")
-            int limit) {
+            @JsonProperty("service") String service,
+            @JsonProperty("identifierSpace") String identifierSpace,
+            @JsonProperty("schemaSpace") String schemaSpace,
+            @JsonProperty("type") ReconType type,
+            @JsonProperty("autoMatch") boolean autoMatch,
+            @JsonProperty("columnDetails") List<ColumnDetail> columnDetails,
+            @JsonProperty("limit") int limit) {
         this(service, identifierSpace, schemaSpace,
                 type != null ? type.id : null,
                 type != null ? type.name : null,
@@ -180,16 +170,14 @@ public class StandardReconConfig extends ReconConfig {
             String service,
             String identifierSpace,
             String schemaSpace,
-            
-            String typeID, 
+
+            String typeID,
             String typeName,
             boolean autoMatch,
-            List<ColumnDetail> columnDetails
-        ) {
+            List<ColumnDetail> columnDetails) {
         this(service, identifierSpace, schemaSpace, typeID, typeName, autoMatch, columnDetails, 0);
     }
-    
-    
+
     /**
      * @param service
      * @param identifierSpace
@@ -198,29 +186,29 @@ public class StandardReconConfig extends ReconConfig {
      * @param typeName
      * @param autoMatch
      * @param columnDetails
-     * @param limit maximum number of results to return (0 = default)
+     * @param limit
+     *            maximum number of results to return (0 = default)
      */
     public StandardReconConfig(
-        String service,
-        String identifierSpace,
-        String schemaSpace,
-        String typeID, 
-        String typeName,
-        boolean autoMatch,
-        List<ColumnDetail> columnDetails,
-        int limit
-    ) {
+            String service,
+            String identifierSpace,
+            String schemaSpace,
+            String typeID,
+            String typeName,
+            boolean autoMatch,
+            List<ColumnDetail> columnDetails,
+            int limit) {
         this.service = service;
         this.identifierSpace = identifierSpace != null ? identifierSpace : DEFAULT_IDENTIFIER_SPACE;
         this.schemaSpace = schemaSpace != null ? schemaSpace : DEFAULT_SCHEMA_SPACE;
-        
+
         this.typeID = typeID;
         this.typeName = typeName;
         this.autoMatch = autoMatch;
         this.columnDetails = columnDetails;
         this.limit = limit;
     }
-    
+
     @JsonProperty("type")
     @JsonInclude(Include.NON_NULL)
     public ReconType getReconType() {
@@ -240,14 +228,12 @@ public class StandardReconConfig extends ReconConfig {
     public String getBriefDescription(Project project, String columnName) {
         return "Reconcile cells in column " + columnName + " to type " + typeID;
     }
-    
+
     public ReconJob createSimpleJob(String query) {
-        /* Same as createJob, but for simpler queries
-         * without any properties. This is much easier
-         * to generate as there is no need for a Project,
-         * Row and Cell: this means the job can be created
-         * outside the usual context of reconciliation (e.g.
-         * in an importer).
+        /*
+         * Same as createJob, but for simpler queries without any properties. This is much easier to generate as there
+         * is no need for a Project, Row and Cell: this means the job can be created outside the usual context of
+         * reconciliation (e.g. in an importer).
          */
         StandardReconJob job = new StandardReconJob();
         try {
@@ -261,20 +247,21 @@ public class StandardReconConfig extends ReconConfig {
             return null;
         }
     }
-    
+
     protected static class QueryProperty {
+
         @JsonProperty("pid")
         String pid;
         @JsonProperty("v")
         Object v;
-        
+
         protected QueryProperty(
                 String pid,
                 Object v) {
             this.pid = pid;
             this.v = v;
         }
-        
+
         @Override
         public String toString() {
             try {
@@ -284,34 +271,35 @@ public class StandardReconConfig extends ReconConfig {
             }
         }
     }
-    
+
     protected static class ReconQuery {
+
         @JsonProperty("query")
         protected String query;
-        
+
         @JsonProperty("type")
         @JsonInclude(Include.NON_NULL)
         protected String typeID;
-        
+
         @JsonProperty("type_strict")
         @JsonInclude(Include.NON_NULL)
         public String isTypeStrict() {
-            if(typeID != null) {
+            if (typeID != null) {
                 return "should";
             }
             return null;
         }
-        
+
         @JsonProperty("properties")
         @JsonInclude(Include.NON_EMPTY)
         protected List<QueryProperty> properties;
-        
+
         // Only send limit if it's non-default (default = 0) to preserve backward
         // compatibility with services which might choke on this (pre-2013)
         @JsonProperty("limit")
         @JsonInclude(Include.NON_DEFAULT)
         protected int limit;
-        
+
         public ReconQuery() {
             super();
             this.query = "";
@@ -331,7 +319,7 @@ public class StandardReconConfig extends ReconConfig {
             this.properties = properties;
             this.limit = limit;
         }
-        
+
         @Override
         public String toString() {
             try {
@@ -341,8 +329,9 @@ public class StandardReconConfig extends ReconConfig {
             }
         }
     }
-    
+
     public static class ReconResult {
+
         @JsonProperty("name")
         public String name;
         @JsonProperty("id")
@@ -378,46 +367,46 @@ public class StandardReconConfig extends ReconConfig {
     @Override
     public ReconJob createJob(Project project, int rowIndex, Row row,
             String columnName, Cell cell) {
-        
+
         StandardReconJob job = new StandardReconJob();
 
-            List<QueryProperty> properties = new ArrayList<>();
-                
-            for (ColumnDetail c : columnDetails) {
-                int detailCellIndex = project.columnModel.getColumnByName(c.columnName).getCellIndex();
-                
-                Cell cell2 = row.getCell(detailCellIndex);
-                if (cell2 == null || !ExpressionUtils.isNonBlankData(cell2.value)) {
-                    int cellIndex = project.columnModel.getColumnByName(columnName).getCellIndex();
-                    
-                    RowDependency rd = project.recordModel.getRowDependency(rowIndex);
-                    if (rd != null && rd.cellDependencies != null) {
-                        int contextRowIndex = rd.cellDependencies[cellIndex].rowIndex;
-                        if (contextRowIndex >= 0 && contextRowIndex < project.rows.size()) {
-                            Row row2 = project.rows.get(contextRowIndex);
-                            
-                            cell2 = row2.getCell(detailCellIndex);
-                        }
-                    }
-                }
-                
-                if (cell2 != null && ExpressionUtils.isNonBlankData(cell2.value)) {
-                    Object v = null;
-                    if (cell2.recon != null && cell2.recon.match != null) {
-                        Map<String, String> recon = new HashMap<>();
-                        recon.put("id", cell2.recon.match.id);
-                        recon.put("name", cell2.recon.match.name);
-                        v = recon;
-                    } else {
-                        v = cell2.value;
-                    }
-                    properties.add(new QueryProperty(c.propertyID, v));
-                }
+        List<QueryProperty> properties = new ArrayList<>();
 
+        for (ColumnDetail c : columnDetails) {
+            int detailCellIndex = project.columnModel.getColumnByName(c.columnName).getCellIndex();
+
+            Cell cell2 = row.getCell(detailCellIndex);
+            if (cell2 == null || !ExpressionUtils.isNonBlankData(cell2.value)) {
+                int cellIndex = project.columnModel.getColumnByName(columnName).getCellIndex();
+
+                RowDependency rd = project.recordModel.getRowDependency(rowIndex);
+                if (rd != null && rd.cellDependencies != null) {
+                    int contextRowIndex = rd.cellDependencies[cellIndex].rowIndex;
+                    if (contextRowIndex >= 0 && contextRowIndex < project.rows.size()) {
+                        Row row2 = project.rows.get(contextRowIndex);
+
+                        cell2 = row2.getCell(detailCellIndex);
+                    }
+                }
             }
-        
+
+            if (cell2 != null && ExpressionUtils.isNonBlankData(cell2.value)) {
+                Object v = null;
+                if (cell2.recon != null && cell2.recon.match != null) {
+                    Map<String, String> recon = new HashMap<>();
+                    recon.put("id", cell2.recon.match.id);
+                    recon.put("name", cell2.recon.match.name);
+                    v = recon;
+                } else {
+                    v = cell2.value;
+                }
+                properties.add(new QueryProperty(c.propertyID, v));
+            }
+
+        }
+
         ReconQuery query = new ReconQuery(cell.value.toString(), typeID, properties, limit);
-        
+
         job.text = cell.value.toString();
         try {
             job.code = ParsingUtilities.defaultWriter.writeValueAsString(query);
@@ -428,7 +417,7 @@ public class StandardReconConfig extends ReconConfig {
         }
         return job;
     }
-    
+
     private HttpClient getHttpClient() {
         if (httpClient == null) {
             httpClient = new HttpClient();
@@ -448,9 +437,9 @@ public class StandardReconConfig extends ReconConfig {
     @Override
     public List<Recon> batchRecon(List<ReconJob> jobs, long historyEntryID) {
         List<Recon> recons = new ArrayList<Recon>(jobs.size());
-        
+
         StringWriter stringWriter = new StringWriter();
-        
+
         stringWriter.write("{");
         for (int i = 0; i < jobs.size(); i++) {
             StandardReconJob job = (StandardReconJob) jobs.get(i);
@@ -462,7 +451,7 @@ public class StandardReconConfig extends ReconConfig {
         }
         stringWriter.write("}");
         String queriesString = stringWriter.toString();
-        
+
         try {
             String responseString = postQueries(service, queriesString);
             ObjectNode o = ParsingUtilities.evaluateJsonStringToObjectNode(responseString);
@@ -504,7 +493,7 @@ public class StandardReconConfig extends ReconConfig {
         while (recons.size() < jobs.size()) {
             recons.add(null);
         }
-        
+
         return recons;
     }
 
@@ -515,22 +504,24 @@ public class StandardReconConfig extends ReconConfig {
         return recon;
     }
 
-    protected Recon createReconServiceResults(String text, ArrayNode resultsList, long historyEntryID)  {
+    protected Recon createReconServiceResults(String text, ArrayNode resultsList, long historyEntryID) {
         Recon recon = new Recon(historyEntryID, identifierSpace, schemaSpace);
-        List<ReconResult> results = ParsingUtilities.mapper.convertValue(resultsList, new TypeReference<List<ReconResult>>() {});
-        
+        List<ReconResult> results = ParsingUtilities.mapper.convertValue(resultsList, new TypeReference<List<ReconResult>>() {
+        });
+
         // Sort results by decreasing score
         results.sort(new Comparator<ReconResult>() {
+
             @Override
             public int compare(ReconResult a, ReconResult b) {
                 return Double.compare(b.score, a.score);
             }
         });
-        
+
         int length = results.size();
         for (int i = 0; i < length; i++) {
             ReconResult result = results.get(i);
-            
+
             ReconCandidate candidate = result.toCandidate();
 
             if (autoMatch && i == 0 && result.match) {
@@ -539,24 +530,24 @@ public class StandardReconConfig extends ReconConfig {
                 recon.judgment = Judgment.Matched;
                 recon.judgmentAction = "auto";
             }
-            
+
             recon.addCandidate(candidate);
         }
-          
+
         computeFeatures(recon, text);
         return recon;
-    } 
+    }
 
     /**
-     * Recomputes the features associated with this reconciliation
-     * object (only if we have at least one candidate).
+     * Recomputes the features associated with this reconciliation object (only if we have at least one candidate).
      * 
-     * @param text the cell value to compare the reconciliation data to
+     * @param text
+     *            the cell value to compare the reconciliation data to
      */
     public void computeFeatures(Recon recon, String text) {
         if (recon.candidates != null && !recon.candidates.isEmpty() && text != null) {
             ReconCandidate candidate = recon.candidates.get(0);
-            
+
             if (candidate.name != null) {
                 recon.setFeature(Recon.Feature_nameMatch, text.equalsIgnoreCase(candidate.name));
                 recon.setFeature(Recon.Feature_nameLevenshtein,
@@ -576,13 +567,13 @@ public class StandardReconConfig extends ReconConfig {
             recon.features = new Object[Recon.Feature_max];
         }
     }
-    
+
     static protected double wordDistance(String s1, String s2) {
         Set<String> words1 = breakWords(s1);
         Set<String> words2 = breakWords(s2);
         return words1.size() >= words2.size() ? wordDistance(words1, words2) : wordDistance(words2, words1);
     }
-    
+
     static protected double wordDistance(Set<String> longWords, Set<String> shortWords) {
         if (longWords.size() == 0) {
             return 0.0;
@@ -596,7 +587,7 @@ public class StandardReconConfig extends ReconConfig {
         }
         return common / longWords.size();
     }
-    
+
     static final protected Set<String> s_stopWords = new HashSet<String>();
     static {
         // FIXME: This is English specific
@@ -609,10 +600,10 @@ public class StandardReconConfig extends ReconConfig {
         s_stopWords.add("at");
         s_stopWords.add("by");
     }
-    
+
     static protected Set<String> breakWords(String s) {
         String[] words = s.toLowerCase().split("\\s+");
-        
+
         Set<String> set = new HashSet<String>(words.length);
         for (String word : words) {
             if (!s_stopWords.contains(word)) {
@@ -622,7 +613,6 @@ public class StandardReconConfig extends ReconConfig {
         return set;
     }
 
-
     @Override
     public String getMode() {
         return "standard-service";
