@@ -118,12 +118,16 @@ public class GrelTests extends RefineTest {
     public void testMath() throws ParsingException {
         String tests[][] = {
                 { "1", "1" },
+                { "-1", "-1" },
+                { "-1 * 2", "-2" },
                 { "1 + 1", "2" },
                 { "1 + 1 + 1", "3" },
                 { "1-1-1", "-1" },
                 { "1-2-3", "-4" },
                 { "1-(2-3)", "2" },
                 { "2*3", "6" },
+                { "2.0*3", "6.0" },
+                { "-2.0*3", "-6.0" },
                 { "3%2", "1" },
                 { "3/2", "1" },
                 { "3.0/2", "1.5" },
