@@ -36,6 +36,7 @@ import java.io.IOException;
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.InputStream;
+import java.io.InputStreamReader;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Properties;
@@ -45,6 +46,9 @@ import okhttp3.mockwebserver.MockResponse;
 import okhttp3.mockwebserver.MockWebServer;
 
 import org.apache.commons.collections.IteratorUtils;
+import org.apache.commons.collections4.IterableUtils;
+import org.apache.commons.csv.CSVFormat;
+import org.apache.commons.csv.CSVRecord;
 import org.apache.commons.fileupload.FileUploadBase;
 import org.apache.commons.io.FileUtils;
 import org.apache.hc.client5.http.entity.mime.MultipartEntityBuilder;
@@ -375,4 +379,29 @@ public class ImportingUtilitiesTests extends ImporterTest {
 
     }
 
+    @Test
+    public void testImportGZipCompressedFiles() throws IOException {
+        String[] filenames = { "persons", "persons.csv.gz" };
+        InputStreamReader reader = null;
+        for (String filename : filenames) {
+            String filePathNoExtension = ClassLoader.getSystemResource(filename).getPath();
+
+            File tmp = File.createTempFile("openrefine-test-" + filename.split("\\.")[0], "", job.getRawDataDir());
+            tmp.deleteOnExit();
+            FileUtils.copyFile(new File(filePathNoExtension), tmp);
+
+            InputStream is = ImportingUtilities.tryOpenAsCompressedFile(tmp, null, null);
+            // assert input stream is not null
+            Assert.assertNotNull(is);
+
+            reader = new InputStreamReader(is);
+            Iterable<CSVRecord> records = CSVFormat.DEFAULT.withFirstRecordAsHeader()
+                    .withIgnoreHeaderCase().withTrim().parse(reader);
+
+            // assert size of iterable is same as number of rows in csv file without header
+            Assert.assertEquals(IterableUtils.size(records), 3);
+        }
+        reader.close();
+    }
+
 }
