@@ -42,22 +42,12 @@ public class ColumnModelTests extends RefineTest {
                 "       \"columnGroups\" : [ ],\n" +
                 "       \"columns\" : [ {\n" +
                 "         \"cellIndex\" : 0,\n" +
-                "         \"constraints\" : \"{}\",\n" +
-                "         \"description\" : \"\",\n" +
-                "         \"format\" : \"default\",\n" +
                 "         \"name\" : \"a\",\n" +
-                "         \"originalName\" : \"a\",\n" +
-                "         \"title\" : \"\",\n" +
-                "         \"type\" : \"\"\n" +
+                "         \"originalName\" : \"a\"\n" +
                 "       }, {\n" +
                 "         \"cellIndex\" : 1,\n" +
-                "         \"constraints\" : \"{}\",\n" +
-                "         \"description\" : \"\",\n" +
-                "         \"format\" : \"default\",\n" +
                 "         \"name\" : \"b\",\n" +
-                "         \"originalName\" : \"b\",\n" +
-                "         \"title\" : \"\",\n" +
-                "         \"type\" : \"\"\n" +
+                "         \"originalName\" : \"b\"\n" +
                 "       } ],\n" +
                 "       \"keyCellIndex\" : 0,\n" +
                 "       \"keyColumnName\" : \"a\"\n" +
