@@ -48,11 +48,6 @@ public class ColumnTests {
         String json = "{\"cellIndex\":4,"
                 + "\"originalName\":\"name\","
                 + "\"name\":\"organization_name\","
-                + "\"type\":\"\","
-                + "\"format\":\"default\","
-                + "\"title\":\"\","
-                + "\"description\":\"\","
-                + "\"constraints\":\"{}\","
                 + "\"reconConfig\":{"
                 + "   \"mode\":\"standard-service\","
                 + "   \"service\":\"https://tools.wmflabs.org/openrefine-wikidata/en/api\","
