@@ -365,10 +365,11 @@ function init() {
       "scripts/util/url.js",
       "scripts/util/string.js",
       "scripts/util/ajax.js",
+      "scripts/util/i18n.js",
+      "scripts/util/csrf.js",
       "scripts/util/menu.js",
       "scripts/util/dialog.js",
       "scripts/util/dom.js",
-      "scripts/util/date-time.js",
       "scripts/util/encoding.js",
       "scripts/util/sign.js",
       "scripts/util/filter-lists.js",
@@ -436,9 +437,9 @@ function init() {
     commonModules.concat([
       "externals/suggest/suggest-4_3a.js",
       "3rdparty/date.js",
-
+      "scripts/util/i18n.js",
+      "scripts/util/csrf.js",
       "scripts/project.js",
-
       "scripts/util/misc.js",
       "scripts/util/url.js",
       "scripts/util/string.js",
@@ -446,7 +447,6 @@ function init() {
       "scripts/util/menu.js",
       "scripts/util/dialog.js",
       "scripts/util/dom.js",
-      "scripts/util/date-time.js",
       "scripts/util/custom-suggest.js",
       "scripts/util/encoding.js",
       "scripts/util/sign.js",
@@ -470,6 +470,12 @@ function init() {
       "scripts/facets/scatterplot-facet.js",
       "scripts/facets/text-search-facet.js",
 
+      "scripts/views/data-table/cell-renderers/null-renderer.js",
+      "scripts/views/data-table/cell-renderers/error-renderer.js",
+      "scripts/views/data-table/cell-renderers/simple-value-renderer.js",
+      "scripts/views/data-table/cell-renderers/recon-renderer.js",
+      "scripts/views/data-table/cell-renderers/registry.js",
+
       "scripts/views/data-table/data-table-view.js",
       "scripts/views/data-table/cell-ui.js",
       "scripts/views/data-table/column-header-ui.js",
@@ -483,7 +489,7 @@ function init() {
       "scripts/reconciliation/standard-service-panel.js",
 
       "scripts/dialogs/expression-preview-dialog.js",
-      "scripts/dialogs/extend-data-preview-dialog.js",
+      "scripts/dialogs/add-column-by-reconciliation.js",
       "scripts/dialogs/clustering-dialog.js",
       "scripts/dialogs/scatterplot-dialog.js",
       "scripts/dialogs/templating-exporter-dialog.js",
@@ -500,7 +506,7 @@ function init() {
     "project/styles",
     module,
     [
-      "externals/suggest/css/suggest-4_3.min.css",
+      "externals/suggest/css/suggest-4_3.css",
       "externals/jquery-ui/css/ui-lightness/jquery-ui.css",
       "externals/imgareaselect/css/imgareaselect-default.css",
 
@@ -530,9 +536,10 @@ function init() {
       "styles/dialogs/column-reordering-dialog.less",
       "styles/dialogs/custom-tabular-exporter-dialog.less",
       "styles/dialogs/sql-exporter-dialog.less",
+      "styles/dialogs/recon-service-selection-dialog.less",
       "styles/reconciliation/recon-dialog.less",
       "styles/reconciliation/standard-service-panel.less",
-      "styles/reconciliation/extend-data-preview-dialog.less",
+      "styles/reconciliation/add-column-by-reconciliation.less",
     ]
   );
 
@@ -540,6 +547,8 @@ function init() {
     "preferences/scripts",
     module,
     commonModules.concat([
+      "scripts/util/i18n.js",
+      "scripts/util/csrf.js",
       "scripts/preferences.js",
     ])
   );
@@ -547,7 +556,7 @@ function init() {
     "preferences/styles",
     module,
     [
-      "externals/suggest/css/suggest-4_3.min.css",
+      "externals/suggest/css/suggest-4_3.css",
       "externals/jquery-ui/css/ui-lightness/jquery-ui.css",
       "styles/jquery-ui-overrides.less",
       "styles/common.less",
