@@ -54,6 +54,7 @@ ClusteringDialog.prototype._createDialog = function() {
     this._elmts.or_dialog_descr.html($.i18n('core-dialogs/cluster-descr'));
     this._elmts.or_dialog_findMore.html($.i18n('core-dialogs/find-more'));
     this._elmts.or_dialog_method.html($.i18n('core-dialogs/method'));
+    this._elmts.or_dialog_distance.html($.i18n('core-dialogs/distance-fun'));
     this._elmts.or_dialog_keyCollision.html($.i18n('core-dialogs/key-collision'));
     this._elmts.or_dialog_neighbor.html($.i18n('core-dialogs/nearest-neighbor'));
     this._elmts.or_dialog_keying.html($.i18n('core-dialogs/keying-function'));
@@ -120,6 +121,8 @@ ClusteringDialog.prototype._createDialog = function() {
     this._elmts.applyCloseButton.on('click',function() { self._onApplyClose(); });
     this._elmts.closeButton.on('click',function() { self._dismiss(); });
 
+    self._level = DialogSystem.showDialog(dialog);
+
     // Fill in all the keyers and distances
     $.get("command/core/get-clustering-functions-and-distances")
     .done(function(data) {
@@ -152,7 +155,6 @@ ClusteringDialog.prototype._createDialog = function() {
              option.prop('selected', 'true');
           }
        }
-       self._level = DialogSystem.showDialog(dialog);
     })
     .fail(function(error) {
             alert($.i18n('core-dialogs/no-clustering-functions-and-distances'));
@@ -215,7 +217,7 @@ ClusteringDialog.prototype._renderTable = function(clusters) {
             var choices = cluster.choices;
             var onClick = function() {
               var parent = $(this).closest("tr");
-              var value = $(this).text();
+              var value = $(this).attr('data-value');
               cluster.value = value;
 
               parent.find("input[type='text']").val(value);
@@ -228,6 +230,7 @@ ClusteringDialog.prototype._renderTable = function(clusters) {
                 var li = document.createElement('li');
                 var entry = entryTemplate.cloneNode();
                 entry.textContent = choice.v.toString().replaceAll(' ', '\xa0');
+                entry.setAttribute('data-value', choice.v.toString());
                 entry.addEventListener('click', onClick);
                 li.append(entry);
                 if (choice.c > 1) {
@@ -305,6 +308,7 @@ ClusteringDialog.prototype._renderTable = function(clusters) {
 };
 
 ClusteringDialog.prototype._cluster = function() {
+    $('#cluster-and-edit-dialog :input').prop('disabled', true);
     $(".clustering-dialog-facet").css("display","none");
     var self = this;
 
@@ -328,6 +332,7 @@ ClusteringDialog.prototype._cluster = function() {
         function(data) {
             self._updateData(data);
             $(".clustering-dialog-facet").css("display","block");
+            $('#cluster-and-edit-dialog :input').prop('disabled', false);
         },
         "json"
     );
@@ -610,6 +615,12 @@ ClusteringDialog.Facet.prototype.update = function(clusters) {
 
     var bins = this._computeDistribution(clusters);
 
+    this._histogram.update(
+        this._min,
+        this._max,
+        this._step,
+        [ this._baseBins, bins ]
+    );
     this._sliderWidget.update(
         this._min,
         this._max,
@@ -617,12 +628,6 @@ ClusteringDialog.Facet.prototype.update = function(clusters) {
         this._from,
         this._to
     );
-    this._histogram.update(
-        this._min,
-        this._max,
-        this._step,
-        [ this._baseBins, bins ]
-    );
 };
 
 ClusteringDialog.Facet.prototype._setRangeIndicators = function() {
