@@ -37,7 +37,7 @@ Refine.DefaultImportingController.prototype._showFileSelectionPanel = function()
   this._selectedMap = {};
   this._prepareFileSelectionPanel();
 
-  this._fileSelectionPanelElmts.nextButton.click(function() {
+  this._fileSelectionPanelElmts.nextButton.on('click',function() {
     self._commitFileSelection();
   });
   this._renderFileSelectionPanel();
@@ -72,7 +72,7 @@ Refine.DefaultImportingController.prototype._prepareFileSelectionPanel = functio
   this._fileSelectionPanelElmts.selectRegexButton.text($.i18n('core-buttons/select'));
   this._fileSelectionPanelElmts.deselectRegexButton.text($.i18n('core-buttons/deselect'));
   
-  this._fileSelectionPanelElmts.startOverButton.click(function() {
+  this._fileSelectionPanelElmts.startOverButton.on('click',function() {
     self._startOver();
   });
 
@@ -150,7 +150,7 @@ Refine.DefaultImportingController.prototype._renderFileSelectionPanelFileTable =
     .attr("type", "checkbox")
     .attr("index", index)
     .appendTo(createLabeledCell())
-    .click(function() {
+    .on('click',function() {
       var fileRecord = files[index];
       if (this.checked) {
         self._selectedMap[fileRecord.location] = fileRecord;
@@ -181,7 +181,7 @@ Refine.DefaultImportingController.prototype._renderFileSelectionPanelControlPane
   var files = this._job.config.retrievalRecord.files;
 
   this._fileSelectionPanelElmts.extensionContainer.empty();
-  this._fileSelectionPanelElmts.selectAllButton.unbind().click(function(evt) {
+  this._fileSelectionPanelElmts.selectAllButton.off().on('click',function(evt) {
     for (var i = 0; i < files.length; i++) {
       var fileRecord = files[i];
       self._selectedMap[fileRecord.location] = fileRecord;
@@ -189,24 +189,25 @@ Refine.DefaultImportingController.prototype._renderFileSelectionPanelControlPane
     self._fileSelectionPanelElmts.filePanel.find("input").prop('checked', true);
     self._updateFileSelectionSummary();
   });
-  this._fileSelectionPanelElmts.deselectAllButton.unbind().click(function(evt) {
+  this._fileSelectionPanelElmts.deselectAllButton.off().on('click',function(evt) {
     self._selectedMap = {};
     self._fileSelectionPanelElmts.filePanel.find("input").prop('checked', false);
     self._updateFileSelectionSummary();
   });
 
-  var table = $('<table></table>')
-  .appendTo(this._fileSelectionPanelElmts.extensionContainer)[0];
+  var table = $('<table></table>').appendTo(this._fileSelectionPanelElmts.extensionContainer)[0];
 
   var renderExtension = function(extension) {
     var tr = table.insertRow(table.rows.length);
-    $('<td>').text(extension.extension).appendTo(tr);
-    $('<td>').text($.i18n('core-index-import/file-count', extension.count)).appendTo(tr);
+    $('<td>').css('width','25%').css('text-align','left').text(extension.extension).appendTo(tr);
+    $('<td>').css('width','25%').css('text-align','left').text($.i18n('core-index-import/file-count', extension.count)).appendTo(tr);
+    var actionTD = $('<td>').css('text-align','right');
+    actionTD.appendTo(tr);
     $('<button>')
     .text($.i18n('core-buttons/select'))
     .addClass("button")
-    .appendTo($('<td>').appendTo(tr))
-    .click(function() {
+    .appendTo(actionTD)
+    .on('click',function() {
       for (var i = 0; i < files.length; i++) {
         var file = files[i];
         if (!(file.location in self._selectedMap)) {
@@ -223,8 +224,9 @@ Refine.DefaultImportingController.prototype._renderFileSelectionPanelControlPane
     $('<button>')
     .text($.i18n('core-buttons/deselect'))
     .addClass("button")
-    .appendTo($('<td>').appendTo(tr))
-    .click(function() {
+    .css('margin-left','5px')
+    .appendTo(actionTD)
+    .on('click',function() {
       for (var i = 0; i < files.length; i++) {
         var file = files[i];
         if (file.location in self._selectedMap) {
@@ -245,7 +247,7 @@ Refine.DefaultImportingController.prototype._renderFileSelectionPanelControlPane
 
   this._updateFileSelectionSummary();
 
-  this._fileSelectionPanelElmts.regexInput.unbind().bind("keyup change input",function() {
+  this._fileSelectionPanelElmts.regexInput.off().on("keyup change input",function() {
     var count = 0;
     var elmts = self._fileSelectionPanelElmts.filePanel
     .find(".default-importing-file-selection-filename")
@@ -263,7 +265,7 @@ Refine.DefaultImportingController.prototype._renderFileSelectionPanelControlPane
     }
       self._fileSelectionPanelElmts.regexSummary.text($.i18n('core-index-import/match-count', count));
   });
-  this._fileSelectionPanelElmts.selectRegexButton.unbind().click(function() {
+  this._fileSelectionPanelElmts.selectRegexButton.off().on('click',function() {
     self._fileSelectionPanelElmts.filePanel
     .find(".default-importing-file-selection-filename")
     .removeClass("highlighted");
@@ -285,7 +287,7 @@ Refine.DefaultImportingController.prototype._renderFileSelectionPanelControlPane
       // Ignore
     }
   });
-  this._fileSelectionPanelElmts.deselectRegexButton.unbind().click(function() {
+  this._fileSelectionPanelElmts.deselectRegexButton.off().on('click',function() {
     self._fileSelectionPanelElmts.filePanel
     .find(".default-importing-file-selection-filename")
     .removeClass("highlighted");
