@@ -78,7 +78,8 @@ DataTableColumnHeaderUI.extendMenu(function(column, columnHeaderUI, menu) {
     );
     
     elmts.cancelButton.on('click',dismiss);
-    elmts.okButton.on('click',function() {
+    elmts.form.on('submit',function(event) {
+      event.preventDefault();
       var columnName = jQueryTrim(elmts.columnNameInput[0].value);
       if (!columnName.length) {
         alert($.i18n('core-views/warning-col-name'));
@@ -150,13 +151,18 @@ DataTableColumnHeaderUI.extendMenu(function(column, columnHeaderUI, menu) {
 
 
     elmts.cancelButton.on('click',dismiss);
-    elmts.okButton.on('click',function() {
+    elmts.form.on('submit',function(event) {
+      event.preventDefault();
       var columnName = jQueryTrim(elmts.columnNameInput[0].value);
       if (!columnName.length) {
         alert($.i18n('core-views/warning-col-name'));
         return;
       }
-      
+      let delay = Number.parseInt(elmts.throttleDelayInput[0].value);
+      if (Number.isNaN(delay) || delay < 0) {
+        alert($.i18n('core-views/warning-throttle-delay-input'));
+        return;
+      }
       Refine.postCoreProcess(
         "add-column-by-fetching-urls", 
         {
@@ -164,7 +170,7 @@ DataTableColumnHeaderUI.extendMenu(function(column, columnHeaderUI, menu) {
           urlExpression: previewWidget.getExpression(true), 
           newColumnName: columnName, 
           columnInsertIndex: columnIndex + 1,
-          delay: elmts.throttleDelayInput[0].value,
+          delay: delay,
           onError: $('input[name="dialog-onerror-choice"]:checked')[0].value,
           cacheResponses: $('input[name="dialog-cache-responses"]')[0].checked,
           httpHeaders: JSON.stringify(elmts.setHttpHeadersContainer.find("input").serializeArray())
@@ -221,6 +227,7 @@ DataTableColumnHeaderUI.extendMenu(function(column, columnHeaderUI, menu) {
     var elmts = DOM.bind(frame);
     elmts.dialogHeader.text($.i18n('core-views/enter-col-name'));
     elmts.columnNameInput.text();
+    elmts.columnNameInput.attr('aria-label',$.i18n('core-views/new-column-name'));
     elmts.columnNameInput[0].value = column.name;
     elmts.okButton.html($.i18n('core-buttons/ok'));
     elmts.cancelButton.text($.i18n('core-buttons/cancel'));
@@ -252,6 +259,7 @@ DataTableColumnHeaderUI.extendMenu(function(column, columnHeaderUI, menu) {
         );
       }
     });
+    elmts.columnNameInput.trigger('focus').trigger('select');
   };
   
 
