@@ -51,7 +51,6 @@ DataTableColumnHeaderUI.extendMenu(function(column, columnHeaderUI, menu) {
       }
     );
   };
-
   MenuSystem.appendTo(menu, [ "core/facet" ], [
     {
       id: "core/text-facet",
@@ -101,7 +100,34 @@ DataTableColumnHeaderUI.extendMenu(function(column, columnHeaderUI, menu) {
       id: "core/scatterplot-facet",
       label: $.i18n('core-views/scatterplot-facet'),
       click: function() {
-        new ScatterplotDialog(column.name);
+          var params = {
+              project: theProject.id
+          };
+          $.getJSON("command/core/get-columns-info?" + $.param(params),(data) => {
+              if (data === null || typeof data.length == 'undefined') {
+                  alert($.i18n('core-dialogs/error-getColumnInfo'));
+                  return;
+              }
+              var numericColumns = [];
+              let isFocusColumnNumeric = false;
+              for (var i = 0; i < data.length; i++) {
+                  if (data[i].is_numeric) {
+                      if (data[i].name === column.name) {
+                          isFocusColumnNumeric = true;
+                      }
+                      numericColumns.push(data[i]);
+                  }
+              }
+              if (!isFocusColumnNumeric) {
+                  alert($.i18n('core-dialogs/column-not-numeric',column.name));
+                  return;
+              } else if (numericColumns.length < 2) {
+                  alert($.i18n('core-dialogs/no-other-numeric-columns',column.name));
+                  return;
+              }
+              new ScatterplotDialog(column.name);
+          });
+
       }
     },
     {},
