@@ -68,36 +68,36 @@ import org.slf4j.LoggerFactory;
 import com.google.refine.Configurations;
 
 /**
- * Main class for Refine server application.  Starts an instance of the
- * Jetty HTTP server / servlet container (inner class Refine Server).
+ * Main class for Refine server application. Starts an instance of the Jetty HTTP server / servlet container (inner
+ * class Refine Server).
  */
 public class Refine {
-    
+
     static private final String DEFAULT_IFACE = "127.0.0.1";
     static private final int DEFAULT_PORT = 3333;
-        
+
     static private int port;
     static private String host;
     static private String iface;
 
     final static Logger logger = LoggerFactory.getLogger("refine");
-        
+
     public static void main(String[] args) throws Exception {
-        
+
         // tell jetty to use SLF4J for logging instead of its own stuff
-        System.setProperty("VERBOSE","false");
-        System.setProperty("org.eclipse.jetty.log.class","org.eclipse.jetty.util.log.Slf4jLog");
-        
+        System.setProperty("VERBOSE", "false");
+        System.setProperty("org.eclipse.jetty.log.class", "org.eclipse.jetty.util.log.Slf4jLog");
+
         // tell macosx to keep the menu associated with the screen and what the app title is
-        System.setProperty("apple.laf.useScreenMenuBar", "true");  
-        System.setProperty("com.apple.eawt.CocoaComponent.CompatibilityMode", "false"); 
+        System.setProperty("apple.laf.useScreenMenuBar", "true");
+        System.setProperty("com.apple.eawt.CocoaComponent.CompatibilityMode", "false");
         System.setProperty("com.apple.mrj.application.apple.menu.about.name", "OpenRefine");
-        
+
         // tell the signpost library to log
-        //System.setProperty("debug","true");
-        
+        // System.setProperty("debug","true");
+
         // set the log verbosity level
-        org.apache.log4j.Logger.getRootLogger().setLevel(Level.toLevel(Configurations.get("refine.verbosity","info")));
+        org.apache.log4j.Logger.getRootLogger().setLevel(Level.toLevel(Configurations.get("refine.verbosity", "info")));
 
         port = Configurations.getInteger("refine.port", DEFAULT_PORT);
         iface = Configurations.get("refine.interface", DEFAULT_IFACE);
@@ -106,9 +106,9 @@ public class Refine {
             host = "*";
         }
 
-        System.setProperty("refine.display.new.version.notice", Configurations.get("refine.display.new.version.notice","true"));
+        System.setProperty("refine.display.new.version.notice", Configurations.get("refine.display.new.version.notice", "true"));
         Refine refine = new Refine();
-        
+
         refine.init(args);
     }
 
@@ -117,7 +117,7 @@ public class Refine {
         RefineServer server = new RefineServer();
         server.init(iface, port, host);
 
-        boolean headless = Configurations.getBoolean("refine.headless",false);
+        boolean headless = Configurations.getBoolean("refine.headless", false);
         if (headless) {
             System.setProperty("java.awt.headless", "true");
             logger.info("Running in headless mode");
@@ -127,23 +127,23 @@ public class Refine {
                 if ("*".equals(host)) {
                     if ("0.0.0.0".equals(iface)) {
                         logger.warn("No refine.host specified while binding to interface 0.0.0.0, guessing localhost.");
-                        client.init("localhost",port);
-                    } else { 
-                        client.init(iface,port);
+                        client.init("localhost", port);
+                    } else {
+                        client.init(iface, port);
                     }
                 } else {
-                    client.init(host,port);
+                    client.init(host, port);
                 }
             } catch (Exception e) {
-                logger.warn("Sorry, some error prevented us from launching the browser for you.\n\n Point your browser to http://" + host + ":" + port + "/ to start using Refine.");
+                logger.warn("Sorry, some error prevented us from launching the browser for you.\n\n Point your browser to http://" + host
+                        + ":" + port + "/ to start using Refine.");
             }
         }
-        
+
         // hook up the signal handlers
         Runtime.getRuntime().addShutdownHook(
-            new Thread(new ShutdownSignalHandler(server))
-        );
- 
+                new Thread(new ShutdownSignalHandler(server)));
+
         server.join();
     }
 }
@@ -151,13 +151,13 @@ public class Refine {
 /* -------------- Refine Server ----------------- */
 
 class RefineServer extends Server {
-    
+
     final static Logger logger = LoggerFactory.getLogger("refine_server");
-    
+
     public RefineServer() {
         super(createThreadPool());
     }
-    
+
     private static ThreadPool createThreadPool() {
         int maxThreads = Configurations.getInteger("refine.queue.size", 30);
         int maxQueue = Configurations.getInteger("refine.queue.max_size", 300);
@@ -165,9 +165,9 @@ class RefineServer extends Server {
         LinkedBlockingQueue<Runnable> queue = new LinkedBlockingQueue<Runnable>(maxQueue);
         return new ThreadPoolExecutorAdapter(new ThreadPoolExecutor(maxThreads, maxQueue, keepAliveTime, TimeUnit.SECONDS, queue));
     }
-        
+
     private ThreadPoolExecutor threadPool;
-    
+
     public void init(String iface, int port, String host) throws Exception {
         logger.info("Starting Server bound to '" + iface + ":" + port + "'");
 
@@ -175,17 +175,17 @@ class RefineServer extends Server {
         if (memory != null) {
             logger.info("refine.memory size: " + memory + " JVM Max heap: " + Runtime.getRuntime().maxMemory());
         }
-        
+
         HttpConfiguration httpConfig = new HttpConfiguration();
         httpConfig.setSendServerVersion(false);
         HttpConnectionFactory httpFactory = new HttpConnectionFactory(httpConfig);
         ServerConnector connector = new ServerConnector(this, httpFactory);
         connector.setPort(port);
         connector.setHost(iface);
-        connector.setIdleTimeout(Configurations.getInteger("server.connection.max_idle_time",60000));
+        connector.setIdleTimeout(Configurations.getInteger("server.connection.max_idle_time", 60000));
         this.addConnector(connector);
 
-        File webapp = new File(Configurations.get("refine.webapp","main/webapp"));
+        File webapp = new File(Configurations.get("refine.webapp", "main/webapp"));
 
         if (!isWebapp(webapp)) {
             webapp = new File("main/webapp");
@@ -198,9 +198,9 @@ class RefineServer extends Server {
             }
         }
 
-        final String contextPath = Configurations.get("refine.context_path","/");
-        final int maxFormContentSize = Configurations.getInteger("refine.max_form_content_size", 64*1048576); // 64MB
-        
+        final String contextPath = Configurations.get("refine.context_path", "/");
+        final int maxFormContentSize = Configurations.getInteger("refine.max_form_content_size", 64 * 1048576); // 64MB
+
         logger.info("Initializing context: '" + contextPath + "' from '" + webapp.getAbsolutePath() + "'");
         WebAppContext context = new WebAppContext(webapp.getAbsolutePath(), contextPath);
         context.setMaxFormContentSize(maxFormContentSize);
@@ -212,7 +212,7 @@ class RefineServer extends Server {
             wrapper.setHandler(context);
             this.setHandler(wrapper);
         }
-        
+
         this.setStopAtShutdown(true);
         StatisticsHandler handler = new StatisticsHandler();
         handler.setServer(this);
@@ -223,14 +223,14 @@ class RefineServer extends Server {
         // right away but it will continue to process the ones that
         // are in execution for the given timeout before attempting to stop
         // NOTE: this is *not* a blocking method, it just sets a parameter
-        //       that _server.stop() will rely on
+        // that _server.stop() will rely on
         this.setStopTimeout(30000);
 
         // Enable context autoreloading
-        if (Configurations.getBoolean("refine.autoreload",false)) {
+        if (Configurations.getBoolean("refine.autoreload", false)) {
             scanForUpdates(webapp, context);
         }
-        
+
         // start the server
         try {
             this.start();
@@ -238,12 +238,12 @@ class RefineServer extends Server {
             logger.error("Failed to start server - is there another copy running already on this port/address?");
             throw e;
         }
-        
+
         configure(context);
     }
-    
+
     @Override
-    protected void doStop() throws Exception {    
+    protected void doStop() throws Exception {
         try {
             // shutdown our scheduled tasks first, if any
             if (threadPool != null) {
@@ -257,7 +257,7 @@ class RefineServer extends Server {
         // then let the parent stop
         super.doStop();
     }
-        
+
     static private boolean isWebapp(File dir) {
         if (dir == null) {
             return false;
@@ -268,7 +268,7 @@ class RefineServer extends Server {
         File webXml = new File(dir, "WEB-INF/web.xml");
         return webXml.exists() && webXml.canRead();
     }
-    
+
     static private void scanForUpdates(final File contextRoot, final WebAppContext context) {
         List<File> scanList = new ArrayList<File>();
 
@@ -279,11 +279,12 @@ class RefineServer extends Server {
         logger.info("Starting autoreloading scanner... ");
 
         Scanner scanner = new Scanner();
-        scanner.setScanInterval(Configurations.getInteger("refine.scanner.period",1));
+        scanner.setScanInterval(Configurations.getInteger("refine.scanner.period", 1));
         scanner.setScanDirs(scanList);
         scanner.setReportExistingFilesOnStartup(false);
 
         scanner.addListener(new Scanner.BulkListener() {
+
             @Override
             public void filesChanged(@SuppressWarnings("rawtypes") List changedFiles) {
                 try {
@@ -292,7 +293,7 @@ class RefineServer extends Server {
 
                     logger.info("Starting context: " + contextRoot.getAbsolutePath());
                     context.start();
-                    
+
                     configure(context);
                 } catch (Exception ex) {
                     throw new RuntimeException(ex);
@@ -306,9 +307,10 @@ class RefineServer extends Server {
             e.printStackTrace();
         }
     }
-    
+
     static private void findFiles(final String extension, File baseDir, final Collection<File> found) {
         baseDir.listFiles(new FileFilter() {
+
             @Override
             public boolean accept(File pathname) {
                 if (pathname.isDirectory()) {
@@ -323,14 +325,15 @@ class RefineServer extends Server {
 
     // inject configuration parameters in the servlets
     // NOTE: this is done *after* starting the server because jetty might override the init
-    // parameters if we set them in the webapp context upon reading the web.xml file    
+    // parameters if we set them in the webapp context upon reading the web.xml file
 
     static private void configure(WebAppContext context) throws Exception {
         ServletHolder servlet = context.getServletHandler().getServlet("refine");
         if (servlet != null) {
             servlet.setInitParameter("refine.data", getDataDir());
             servlet.setInitParameter("butterfly.modules.path", getDataDir() + "/extensions");
-            servlet.setInitParameter("refine.autosave", Configurations.get("refine.autosave", "5")); // default: 5 minutes
+            servlet.setInitParameter("refine.autosave", Configurations.get("refine.autosave", "5")); // default: 5
+                                                                                                     // minutes
             servlet.setInitOrder(1);
             servlet.doStart();
         }
@@ -338,7 +341,7 @@ class RefineServer extends Server {
         servlet = context.getServletHandler().getServlet("refine-broker");
         if (servlet != null) {
             servlet.setInitParameter("refine.data", getDataDir() + "/broker");
-            servlet.setInitParameter("refine.development", Configurations.get("refine.development","false"));
+            servlet.setInitParameter("refine.development", Configurations.get("refine.development", "false"));
             servlet.setInitOrder(1);
             servlet.doStart();
         }
@@ -349,15 +352,15 @@ class RefineServer extends Server {
         if (data_dir != null) {
             return data_dir;
         }
-        
+
         File dataDir = null;
         File grefineDir = null;
         File gridworksDir = null;
-        
+
         String os = System.getProperty("os.name").toLowerCase();
         if (os.contains("windows")) {
             File parentDir = null;
-            String appData = System.getenv("APPDATA"); 
+            String appData = System.getenv("APPDATA");
             if (appData != null && appData.length() > 0) {
                 // e.g., C:\Users\[userid]\AppData\Roaming
                 parentDir = new File(appData);
@@ -373,21 +376,21 @@ class RefineServer extends Server {
             if (parentDir == null) {
                 parentDir = new File(".");
             }
-            
+
             dataDir = new File(parentDir, "OpenRefine");
             grefineDir = new File(new File(parentDir, "Google"), "Refine");
             gridworksDir = new File(parentDir, "Gridworks");
         } else if (os.contains("os x")) {
             // on macosx, use "~/Library/Application Support"
             String home = System.getProperty("user.home");
-            
+
             String data_home = (home != null) ? home + "/Library/Application Support/OpenRefine" : ".openrefine";
             dataDir = new File(data_home);
-            
+
             String grefine_home = (home != null) ? home + "/Library/Application Support/Google/Refine" : ".google-refine";
             grefineDir = new File(grefine_home);
-            
-            String gridworks_home = (home != null) ? home + "/Library/Application Support/Gridworks" : ".gridworks"; 
+
+            String gridworks_home = (home != null) ? home + "/Library/Application Support/Gridworks" : ".gridworks";
             gridworksDir = new File(gridworks_home);
         } else { // most likely a UNIX flavor
             // start with the XDG environment
@@ -400,39 +403,39 @@ class RefineServer extends Server {
                 }
                 data_home = home + "/.local/share";
             }
-            
+
             dataDir = new File(data_home + "/openrefine");
             grefineDir = new File(data_home + "/google/refine");
             gridworksDir = new File(data_home + "/gridworks");
         }
-        
+
         // If refine data dir doesn't exist, try to find and move Google Refine or Gridworks data dir over
         if (!dataDir.exists()) {
             if (grefineDir.exists()) {
                 if (gridworksDir.exists()) {
                     logger.warn("Found both Gridworks: " + gridworksDir
-                            + " & Googld Refine dirs " + grefineDir) ;
+                            + " & Googld Refine dirs " + grefineDir);
                 }
                 if (grefineDir.renameTo(dataDir)) {
-                    logger.info("Renamed Google Refine directory " + grefineDir 
+                    logger.info("Renamed Google Refine directory " + grefineDir
                             + " to " + dataDir);
                 } else {
-                    logger.error("FAILED to rename Google Refine directory " 
-                            + grefineDir 
+                    logger.error("FAILED to rename Google Refine directory "
+                            + grefineDir
                             + " to " + dataDir);
-                } 
+                }
             } else if (gridworksDir.exists()) {
                 if (gridworksDir.renameTo(dataDir)) {
-                    logger.info("Renamed Gridworks directory " + gridworksDir 
+                    logger.info("Renamed Gridworks directory " + gridworksDir
                             + " to " + dataDir);
                 } else {
-                    logger.error("FAILED to rename Gridworks directory " 
-                            + gridworksDir 
+                    logger.error("FAILED to rename Gridworks directory "
+                            + gridworksDir
                             + " to " + dataDir);
                 }
             }
         }
-        
+
         // Either rename failed or nothing to rename - create a new one
         if (!dataDir.exists()) {
             logger.info("Creating new workspace directory " + dataDir);
@@ -440,14 +443,13 @@ class RefineServer extends Server {
                 logger.error("FAILED to create new workspace directory " + dataDir);
             }
         }
-        
+
         return dataDir.getAbsolutePath();
     }
-    
+
     /**
-     * For Windows file paths that contain user IDs with non ASCII characters,
-     * those characters might get replaced with ?. We need to use the environment
-     * APPDATA value to substitute back the original user ID.
+     * For Windows file paths that contain user IDs with non ASCII characters, those characters might get replaced with
+     * ?. We need to use the environment APPDATA value to substitute back the original user ID.
      */
     static private String fixWindowsUnicodePath(String path) {
         int q = path.indexOf('?');
@@ -455,7 +457,7 @@ class RefineServer extends Server {
             return path;
         }
         int pathSep = path.indexOf(File.separatorChar, q);
-        
+
         String goodPath = System.getenv("APPDATA");
         if (goodPath == null || goodPath.length() == 0) {
             goodPath = System.getenv("USERPROFILE");
@@ -463,39 +465,39 @@ class RefineServer extends Server {
                 goodPath = goodPath + File.separator;
             }
         }
-        
+
         int goodPathSep = goodPath.indexOf(File.separatorChar, q);
-        
+
         return path.substring(0, q) + goodPath.substring(q, goodPathSep) + path.substring(pathSep);
     }
-    
+
 }
 
 /* -------------- Refine Client ----------------- */
 
 class RefineClient extends JFrame implements ActionListener {
-    
+
     private static final long serialVersionUID = 7886547342175227132L;
 
     final static Logger logger = LoggerFactory.getLogger("refine-client");
 
     private URI uri;
-    
+
     public void init(String host, int port) throws Exception {
         uri = new URI("http://" + host + ":" + port + "/");
         openBrowser();
     }
-    
+
     @Override
-    public void actionPerformed(ActionEvent e) { 
-        String item = e.getActionCommand(); 
+    public void actionPerformed(ActionEvent e) {
+        String item = e.getActionCommand();
         if (item.startsWith("Open")) {
             openBrowser();
         }
-    } 
-    
+    }
+
     private void openBrowser() {
-        if (!Desktop.getDesktop().isSupported(Desktop.Action.BROWSE)) {
+        if (!Desktop.getDesktop().isSupported(Desktop.Action.BROWSE) || System.getenv("SNAP") != null) {
             try {
                 openBrowserFallback();
             } catch (IOException e) {
@@ -513,20 +515,20 @@ class RefineClient extends JFrame implements ActionListener {
     private void openBrowserFallback() throws IOException {
         Runtime rt = Runtime.getRuntime();
 
-        if(SystemUtils.IS_OS_WINDOWS) {
+        if (SystemUtils.IS_OS_WINDOWS) {
             rt.exec("rundll32 url.dll,FileProtocolHandler " + uri);
         } else if (SystemUtils.IS_OS_MAC_OSX) {
             rt.exec("open " + uri);
         } else if (SystemUtils.IS_OS_LINUX) {
             rt.exec("xdg-open " + uri);
         } else {
-            logger.warn("Java Desktop class not supported on this platform. Please open %s in your browser",uri.toString());
+            logger.warn("Java Desktop class not supported on this platform. Please open %s in your browser", uri.toString());
         }
     }
 }
 
 class ShutdownSignalHandler implements Runnable {
-    
+
     private Server _server;
 
     public ShutdownSignalHandler(Server server) {
@@ -545,4 +547,3 @@ class ShutdownSignalHandler implements Runnable {
     }
 
 }
-    
